@@ -33,7 +33,7 @@ data_raw = pd.read_csv(filepath, index_col=False)
 data = data_raw.dropna()
 
 #mod = smd.Poisson.from_formula('accident ~ yr_con + op_75_79', data=dat)
-# Don't use formula for tests against Stata because intercept needs to be last
+# Do not use formula for tests against Stata because intercept needs to be last
 endog = data['accident']
 exog_data = data['yr_con op_75_79'.split()]
 exog = add_constant(exog_data, prepend=False)
@@ -42,7 +42,7 @@ exposure = np.asarray(data['service'])
 
 
 # TODO get the test methods from regression/tests
-class CheckCountRobustMixin(object):
+class CheckCountRobustMixin:
 
 
     def test_basic(self):
@@ -437,12 +437,12 @@ class TestNegbinCluExposureFit(CheckCountRobustMixin):
         cls.corr_fact = cls.get_correction_factor(cls.res1)
 
 
-class CheckDiscreteGLM(object):
+class CheckDiscreteGLM:
     # compare GLM with other models, no verified reference results
 
     def test_basic(self):
-        res1 = self.res1
-        res2 = self.res2
+        res1 = self.res1  # GLM model
+        res2 = self.res2  # comparison model, discrete or OLS
 
         assert_equal(res1.cov_type, self.cov_type)
         assert_equal(res2.cov_type, self.cov_type)
@@ -451,6 +451,71 @@ class CheckDiscreteGLM(object):
         assert_allclose(res1.params, res2.params, rtol=rtol)
         assert_allclose(res1.bse, res2.bse, rtol=1e-10)
 
+    def test_score_hessian(self):
+        res1 = self.res1
+        res2 = self.res2
+
+        # We need to fix scale in GLM and OLS,
+        # discrete MLE have it always fixed
+        if isinstance(res2.model, OLS):
+            kwds = {'scale': res2.scale}
+        else:
+            kwds = {}
+        if isinstance(res2.model, OLS):
+            sgn = + 1
+        else:
+            sgn = -1  # see #4714
+
+        score1 = res1.model.score(res1.params * 0.98, scale=res1.scale)
+        score2 = res2.model.score(res1.params * 0.98, **kwds)
+        assert_allclose(score1, score2, rtol=1e-13)
+
+        hess1 = res1.model.hessian(res1.params, scale=res1.scale)
+        hess2 = res2.model.hessian(res1.params, **kwds)
+        assert_allclose(hess1, hess2, rtol=1e-10)
+
+        if isinstance(res2.model, OLS):
+            # skip the rest
+            return
+        scoref1 = res1.model.score_factor(res1.params, scale=res1.scale)
+        scoref2 = res2.model.score_factor(res1.params, **kwds)
+        assert_allclose(scoref1, scoref2, rtol=1e-10)
+
+        hessf1 = res1.model.hessian_factor(res1.params, scale=res1.scale)
+        hessf2 = res2.model.hessian_factor(res1.params, **kwds)
+        assert_allclose(sgn * hessf1, hessf2, rtol=1e-10)
+
+    def test_score_test(self):
+        res1 = self.res1
+        res2 = self.res2
+
+        if isinstance(res2.model, OLS):
+            # skip
+            return
+
+        fitted = self.res1.fittedvalues
+        exog_extra = np.column_stack((fitted**2, fitted**3))
+        res_lm1 = res1.score_test(exog_extra, cov_type='nonrobust')
+        res_lm2 = res2.score_test(exog_extra, cov_type='nonrobust')
+        assert_allclose(np.hstack(res_lm1), np.hstack(res_lm2), rtol=5e-7)
+
+
+class TestGLMPoisson(CheckDiscreteGLM):
+
+    @classmethod
+    def setup_class(cls):
+        np.random.seed(987125643)  # not intentional seed
+        endog_count = np.random.poisson(endog)
+        cls.cov_type = 'HC0'
+
+        mod1 = GLM(endog_count, exog, family=families.Poisson())
+        cls.res1 = mod1.fit(cov_type='HC0')
+
+        mod1 = smd.Poisson(endog_count, exog)
+        cls.res2 = mod1.fit(cov_type='HC0')
+
+        cls.res1.rtol = 1e-11
+
 
 class TestGLMLogit(CheckDiscreteGLM):
 
@@ -466,6 +531,20 @@ class TestGLMLogit(CheckDiscreteGLM):
         cls.res2 = mod1.fit(cov_type='cluster', cov_kwds=dict(groups=group))
 
 
+class TestGLMLogitOffset(CheckDiscreteGLM):
+
+    @classmethod
+    def setup_class(cls):
+        endog_bin = (endog > endog.mean()).astype(int)
+        cls.cov_type = 'cluster'
+        offset = np.ones(endog_bin.shape[0])
+
+        mod1 = GLM(endog_bin, exog, family=families.Binomial(), offset=offset)
+        cls.res1 = mod1.fit(cov_type='cluster', cov_kwds=dict(groups=group))
+
+        mod1 = smd.Logit(endog_bin, exog, offset=offset)
+        cls.res2 = mod1.fit(cov_type='cluster', cov_kwds=dict(groups=group))
+
 class TestGLMProbit(CheckDiscreteGLM):
 
     @classmethod
@@ -473,7 +552,7 @@ class TestGLMProbit(CheckDiscreteGLM):
         endog_bin = (endog > endog.mean()).astype(int)
         cls.cov_type = 'cluster'
 
-        mod1 = GLM(endog_bin, exog, family=families.Binomial(link=links.probit()))
+        mod1 = GLM(endog_bin, exog, family=families.Binomial(link=links.Probit()))
         cls.res1 = mod1.fit(method='newton',
                             cov_type='cluster', cov_kwds=dict(groups=group))
 
@@ -484,14 +563,33 @@ class TestGLMProbit(CheckDiscreteGLM):
     def test_score_hessian(self):
         res1 = self.res1
         res2 = self.res2
-        # Note scale is fixed at 1, so we don't need to fix it explicitly
+        # Note scale is fixed at 1, so we do not need to fix it explicitly
         score1 = res1.model.score(res1.params * 0.98)
         score2 = res2.model.score(res1.params * 0.98)
         assert_allclose(score1, score2, rtol=1e-13)
 
         hess1 = res1.model.hessian(res1.params)
         hess2 = res2.model.hessian(res1.params)
-        assert_allclose(hess1, hess2, rtol=1e-10)
+        assert_allclose(hess1, hess2, rtol=1e-13)
+
+
+class TestGLMProbitOffset(CheckDiscreteGLM):
+
+    @classmethod
+    def setup_class(cls):
+        endog_bin = (endog > endog.mean()).astype(int)
+        cls.cov_type = 'cluster'
+        offset = np.ones(endog_bin.shape[0])
+
+        mod1 = GLM(endog_bin, exog,
+                   family=families.Binomial(link=links.Probit()),
+                   offset=offset)
+        cls.res1 = mod1.fit(method='newton',
+                            cov_type='cluster', cov_kwds=dict(groups=group))
+
+        mod1 = smd.Probit(endog_bin, exog, offset=offset)
+        cls.res2 = mod1.fit(cov_type='cluster', cov_kwds=dict(groups=group))
+        cls.rtol = 1e-6
 
 
 class TestGLMGaussNonRobust(CheckDiscreteGLM):
