@@ -4,13 +4,14 @@ Empirical CDF Functions
 import numpy as np
 from scipy.interpolate import interp1d
 
+
 def _conf_set(F, alpha=.05):
     r"""
     Constructs a Dvoretzky-Kiefer-Wolfowitz confidence band for the eCDF.
 
     Parameters
     ----------
-    F : array-like
+    F : array_like
         The empirical distributions
     alpha : float
         Set alpha for a (1 - alpha) % confidence band.
@@ -19,7 +20,8 @@ def _conf_set(F, alpha=.05):
     -----
     Based on the DKW inequality.
 
-    .. math:: P \left( \sup_x \left| F(x) - \hat(F)_n(X) \right| > \epsilon \right) \leq 2e^{-2n\epsilon^2}
+    .. math:: P \left( \sup_x \left| F(x) - \hat(F)_n(X) \right| >
+       \epsilon \right) \leq 2e^{-2n\epsilon^2}
 
     References
     ----------
@@ -31,7 +33,8 @@ def _conf_set(F, alpha=.05):
     upper = np.clip(F + epsilon, 0, 1)
     return lower, upper
 
-class StepFunction(object):
+
+class StepFunction:
     """
     A basic step function.
 
@@ -41,8 +44,8 @@ class StepFunction(object):
 
     Parameters
     ----------
-    x : array-like
-    y : array-like
+    x : array_like
+    y : array_like
     ival : float
         ival is the value given to the values to the left of x[0]. Default
         is 0.
@@ -55,7 +58,8 @@ class StepFunction(object):
     Examples
     --------
     >>> import numpy as np
-    >>> from statsmodels.distributions.empirical_distribution import StepFunction
+    >>> from statsmodels.distributions.empirical_distribution import (
+    >>>     StepFunction)
     >>>
     >>> x = np.arange(20)
     >>> y = np.arange(20)
@@ -74,7 +78,7 @@ class StepFunction(object):
     3.0
     """
 
-    def __init__(self, x, y, ival=0., sorted=False, side='left'):
+    def __init__(self, x, y, ival=0., sorted=False, side='left'):  # noqa
 
         if side.lower() not in ['right', 'left']:
             msg = "side can take the values 'right' or 'left'"
@@ -105,13 +109,14 @@ class StepFunction(object):
         tind = np.searchsorted(self.x, time, self.side) - 1
         return self.y[tind]
 
+
 class ECDF(StepFunction):
     """
     Return the Empirical CDF of an array as a step function.
 
     Parameters
     ----------
-    x : array-like
+    x : array_like
         Observations
     side : {'left', 'right'}, optional
         Default is 'right'. Defines the shape of the intervals constituting the
@@ -135,7 +140,7 @@ class ECDF(StepFunction):
         x = np.array(x, copy=True)
         x.sort()
         nobs = len(x)
-        y = np.linspace(1./nobs,1,nobs)
+        y = np.linspace(1./nobs, 1, nobs)
         super(ECDF, self).__init__(x, y, side=side, sorted=True)
         # TODO: make `step` an arg and have a linear interpolation option?
         # This is the path with `step` is True
@@ -145,6 +150,71 @@ class ECDF(StepFunction):
         # fixed.  See GH#5701.
 
 
+class ECDFDiscrete(StepFunction):
+    """
+    Return the Empirical Weighted CDF of an array as a step function.
+
+    Parameters
+    ----------
+    x : array_like
+        Data values. If freq_weights is None, then x is treated as observations
+        and the ecdf is computed from the frequency counts of unique values
+        using nunpy.unique.
+        If freq_weights is not None, then x will be taken as the support of the
+        mass point distribution with freq_weights as counts for x values.
+        The x values can be arbitrary sortable values and need not be integers.
+    freq_weights : array_like
+        Weights of the observations.  sum(freq_weights) is interpreted as nobs
+        for confint.
+        If freq_weights is None, then the frequency counts for unique values
+        will be computed from the data x.
+    side : {'left', 'right'}, optional
+        Default is 'right'. Defines the shape of the intervals constituting the
+        steps. 'right' correspond to [a, b) intervals and 'left' to (a, b].
+
+    Returns
+    -------
+    Weighted ECDF as a step function.
+
+    Examples
+    --------
+    >>> import numpy as np
+    >>> from statsmodels.distributions.empirical_distribution import (
+    >>>     ECDFDiscrete)
+    >>>
+    >>> ewcdf = ECDFDiscrete([3, 3, 1, 4])
+    >>> ewcdf([3, 55, 0.5, 1.5])
+    array([0.75, 1.  , 0.  , 0.25])
+    >>>
+    >>> ewcdf = ECDFDiscrete([3, 1, 4], [1.25, 2.5, 5])
+    >>>
+    >>> ewcdf([3, 55, 0.5, 1.5])
+    array([0.42857143, 1., 0. , 0.28571429])
+    >>> print('e1 and e2 are equivalent ways of defining the same ECDF')
+    e1 and e2 are equivalent ways of defining the same ECDF
+    >>> e1 = ECDFDiscrete([3.5, 3.5, 1.5, 1, 4])
+    >>> e2 = ECDFDiscrete([3.5, 1.5, 1, 4], freq_weights=[2, 1, 1, 1])
+    >>> print(e1.x, e2.x)
+    [-inf  1.   1.5  3.5  4. ] [-inf  1.   1.5  3.5  4. ]
+    >>> print(e1.y, e2.y)
+    [0.  0.2 0.4 0.8 1. ] [0.  0.2 0.4 0.8 1. ]
+    """
+    def __init__(self, x, freq_weights=None, side='right'):
+        if freq_weights is None:
+            x, freq_weights = np.unique(x, return_counts=True)
+        else:
+            x = np.asarray(x)
+        assert len(freq_weights) == len(x)
+        w = np.asarray(freq_weights)
+        sw = np.sum(w)
+        assert sw > 0
+        ax = x.argsort()
+        x = x[ax]
+        y = np.cumsum(w[ax])
+        y = y / sw
+        super(ECDFDiscrete, self).__init__(x, y, side=side, sorted=True)
+
+
 def monotone_fn_inverter(fn, x, vectorized=True, **keywords):
     """
     Given a monotone function fn (no checking is done to verify monotonicity)
@@ -163,23 +233,3 @@ def monotone_fn_inverter(fn, x, vectorized=True, **keywords):
     a = np.argsort(y)
 
     return interp1d(y[a], x[a])
-
-if __name__ == "__main__":
-    #TODO: Make sure everything is correctly aligned and make a plotting
-    # function
-    from statsmodels.compat.python import urlopen
-    import matplotlib.pyplot as plt
-    nerve_data = urlopen('http://www.statsci.org/data/general/nerve.txt')
-    nerve_data = np.loadtxt(nerve_data)
-    x = nerve_data / 50. # was in 1/50 seconds
-    cdf = ECDF(x)
-    x.sort()
-    F = cdf(x)
-    plt.step(x, F, where='post')
-    lower, upper = _conf_set(F)
-    plt.step(x, lower, 'r', where='post')
-    plt.step(x, upper, 'r', where='post')
-    plt.xlim(0, 1.5)
-    plt.ylim(0, 1.05)
-    plt.vlines(x, 0, .05)
-    plt.show()
