@@ -1,15 +1,24 @@
+from statsmodels.compat.python import lmap, lrange, lzip
+
 import copy
+from itertools import zip_longest
 import time
 
-from statsmodels.compat.python import range, lrange, lmap, lzip, zip_longest
 import numpy as np
+
 from statsmodels.iolib.table import SimpleTable
-from statsmodels.iolib.tableformatting import (gen_fmt, fmt_2,
-                                               fmt_params, fmt_2cols)
+from statsmodels.iolib.tableformatting import (
+    fmt_2,
+    fmt_2cols,
+    fmt_params,
+    gen_fmt,
+)
+
 from .summary2 import _model_types
 
 
 def forg(x, prec=3):
+    x = np.squeeze(x)
     if prec == 3:
         # for 3 decimals
         if (abs(x) >= 1e4) or (abs(x) < 1e-4):
@@ -57,14 +66,14 @@ def summary(self, yname=None, xname=None, title=0, alpha=.05,
     """
     Parameters
     ----------
-    yname : string
+    yname : str
             optional, Default is `Y`
-    xname : list of strings
+    xname : list[str]
             optional, Default is `X.#` for # in p the number of regressors
     Confidance interval : (0,1) not implimented
-    title : string
+    title : str
             optional, Defualt is 'Generalized linear model'
-    returns : string
+    returns : str
               'text', 'table', 'csv', 'latex', 'html'
 
     Returns
@@ -97,7 +106,7 @@ def summary(self, yname=None, xname=None, title=0, alpha=.05,
     Examples (needs updating)
     --------
     >>> import statsmodels as sm
-    >>> data = sm.datasets.longley.load(as_pandas=False)
+    >>> data = sm.datasets.longley.load()
     >>> data.exog = sm.add_constant(data.exog)
     >>> ols_results = sm.OLS(data.endog, data.exog).results
     >>> print ols_results.summary()
@@ -291,7 +300,7 @@ def summary_top(results, title=None, gleft=None, gright=None, yname=None, xname=
           ('No. Observations:', lambda: [d_or_f(results.nobs)]),
           ('Df Model:', lambda: [d_or_f(results.df_model)]),
           ('Df Residuals:', lambda: [d_or_f(results.df_resid)]),
-          ('Log-Likelihood:', lambda: ["%#8.5g" % results.llf])  # doesn't exist for RLM - exception
+          ('Log-Likelihood:', lambda: ["%#8.5g" % results.llf])  # does not exist for RLM - exception
     ])
 
     if title is None:
@@ -346,7 +355,7 @@ def summary_top(results, title=None, gleft=None, gright=None, yname=None, xname=
             # fill up with blank lines to same length, just to keep it symmetric
             gen_left += [(' ', ' ')] * (len(gen_right) - len(gen_left))
 
-        # padding in SimpleTable doesn't work like I want
+        # padding in SimpleTable does not work like I want
         #force extra spacing and exact string length in right table
         gen_right = [('%-21s' % ('  '+k), v) for k,v in gen_right]
         gen_stubs_right, gen_data_right = zip_longest(*gen_right) #transpose row col
@@ -385,9 +394,9 @@ def summary_params(results, yname=None, xname=None, alpha=.05, use_t=True,
     res : results instance
         some required information is directly taken from the result
         instance
-    yname : string or None
+    yname : {str, None}
         optional name for the endogenous variable, default is "y"
-    xname : list of strings or None
+    xname : {list[str], None}
         optional names for the exogenous variables, default is "var_xx"
     alpha : float
         significance level for the confidence intervals
@@ -410,16 +419,17 @@ def summary_params(results, yname=None, xname=None, alpha=.05, use_t=True,
 
     if isinstance(results, tuple):
         # for multivariate endog
-        # TODO: check whether I don't want to refactor this
+        # TODO: check whether I do not want to refactor this
         #we need to give parameter alpha to conf_int
         results, params, std_err, tvalues, pvalues, conf_int = results
     else:
         params = results.params
         std_err = results.bse
-        tvalues = results.tvalues  #is this sometimes called zvalues
+        tvalues = results.tvalues  # is this sometimes called zvalues
         pvalues = results.pvalues
         conf_int = results.conf_int(alpha)
-
+    if params.size == 0:
+        return SimpleTable([['No Model Parameters']])
     # Dictionary to store the header names for the parameter part of the
     # summary table. look up by modeltype
     if use_t:
@@ -466,9 +476,9 @@ def summary_params_frame(results, yname=None, xname=None, alpha=.05,
     res : results instance
         some required information is directly taken from the result
         instance
-    yname : string or None
+    yname : {str, None}
         optional name for the endogenous variable, default is "y"
-    xname : list of strings or None
+    xname : {list[str], None}
         optional names for the exogenous variables, default is "var_xx"
     alpha : float
         significance level for the confidence intervals
@@ -491,7 +501,7 @@ def summary_params_frame(results, yname=None, xname=None, alpha=.05,
 
     if isinstance(results, tuple):
         # for multivariate endog
-        # TODO: check whether I don't want to refactor this
+        # TODO: check whether I do not want to refactor this
         #we need to give parameter alpha to conf_int
         results, params, std_err, tvalues, pvalues, conf_int = results
     else:
@@ -527,11 +537,11 @@ def summary_params_2d(result, extras=None, endog_names=None, exog_names=None,
     ----------
     result : result instance
         the result instance with params and attributes in extras
-    extras : list of strings
+    extras : list[str]
         additional attributes to add below a parameter row, e.g. bse or tvalues
-    endog_names : None or list of strings
+    endog_names : {list[str], None}
         names for rows of the parameter array (multivariate endog)
-    exog_names : None or list of strings
+    exog_names : {list[str], None}
         names for columns of the parameter array (exog)
     alpha : float
         level for confidence intervals, default 0.95
@@ -586,9 +596,9 @@ def summary_params_2dflat(result, endog_names=None, exog_names=None, alpha=0.05,
     ----------
     result : result instance
         the result instance with params, bse, tvalues and conf_int
-    endog_names : None or list of strings
+    endog_names : {list[str], None}
         names for rows of the parameter array (multivariate endog)
-    exog_names : None or list of strings
+    exog_names : {list[str], None}
         names for columns of the parameter array (exog)
     alpha : float
         level for confidence intervals, default 0.95
@@ -624,7 +634,7 @@ def summary_params_2dflat(result, endog_names=None, exog_names=None, alpha=0.05,
             raise ValueError('endog_names has wrong length')
         n_equ = 1
 
-    #VAR doesn't have conf_int
+    #VAR does not have conf_int
     #params = res.params.T # this is a convention for multi-eq models
 
     # check that we have the right length of names
@@ -716,7 +726,6 @@ def summary_return(tables, return_fmt='text'):
     elif return_fmt == 'latex':
         # TODO: insert \hline after updating SimpleTable
         table = copy.deepcopy(tables[0])
-        del table[-1]
         for part in tables[1:]:
             table.extend(part)
         return table.as_latex_tabular()
@@ -726,8 +735,9 @@ def summary_return(tables, return_fmt='text'):
         raise ValueError('available output formats are text, csv, latex, html')
 
 
-class Summary(object):
-    '''class to hold tables for result summary presentation
+class Summary:
+    """
+    Result summary
 
     Construction does not take any parameters. Tables and text can be added
     with the `add_` methods.
@@ -737,10 +747,10 @@ class Summary(object):
     tables : list of tables
         Contains the list of SimpleTable instances, horizontally concatenated
         tables are not saved separately.
-    extra_txt : string
+    extra_txt : str
         extra lines that are added to the text output, used for warnings
         and explanations.
-    '''
+    """
     def __init__(self):
         self.tables = []
         self.extra_txt = None
@@ -755,32 +765,33 @@ class Summary(object):
         '''Display as HTML in IPython notebook.'''
         return self.as_html()
 
+    def _repr_latex_(self):
+        '''Display as LaTeX when converting IPython notebook to PDF.'''
+        return self.as_latex()
+
     def add_table_2cols(self, res,  title=None, gleft=None, gright=None,
                         yname=None, xname=None):
-        '''add a double table, 2 tables with one column merged horizontally
+        """
+        Add a double table, 2 tables with one column merged horizontally
 
         Parameters
         ----------
         res : results instance
             some required information is directly taken from the result
             instance
-        title : string or None
+        title : str, optional
             if None, then a default title is used.
-        gleft : list of tuples
+        gleft : list[tuple], optional
             elements for the left table, tuples are (name, value) pairs
             If gleft is None, then a default table is created
-        gright : list of tuples or None
+        gright : list[tuple], optional
             elements for the right table, tuples are (name, value) pairs
-        yname : string or None
+        yname : str, optional
             optional name for the endogenous variable, default is "y"
-        xname : list of strings or None
-            optional names for the exogenous variables, default is "var_xx"
-
-        Returns
-        -------
-        None : tables are attached
-
-        '''
+        xname : list[str], optional
+            optional names for the exogenous variables, default is "var_xx".
+            Must match the number of parameters in the model.
+        """
 
         table = summary_top(res, title=title, gleft=gleft, gright=gright,
                             yname=yname, xname=xname)
@@ -795,9 +806,9 @@ class Summary(object):
         res : results instance
             some required information is directly taken from the result
             instance
-        yname : string or None
+        yname : {str, None}
             optional name for the endogenous variable, default is "y"
-        xname : list of strings or None
+        xname : {list[str], None}
             optional names for the exogenous variables, default is "var_xx"
         alpha : float
             significance level for the confidence intervals
@@ -837,7 +848,7 @@ class Summary(object):
 
         Returns
         -------
-        txt : string
+        txt : str
             summary tables and extra text as one string
 
         '''
@@ -851,7 +862,7 @@ class Summary(object):
 
         Returns
         -------
-        latex : string
+        latex : str
             summary tables and extra text as string of Latex
 
         Notes
@@ -871,7 +882,7 @@ class Summary(object):
 
         Returns
         -------
-        csv : string
+        csv : str
             concatenated summary tables in comma delimited format
 
         '''
@@ -885,7 +896,7 @@ class Summary(object):
 
         Returns
         -------
-        html : string
+        html : str
             concatenated summary tables in HTML format
 
         '''
