@@ -5,30 +5,28 @@ from pandas import DataFrame, Index
 import patsy
 
 from statsmodels.regression.linear_model import OLS
-from statsmodels.compat.python import lrange, lmap
+from statsmodels.compat.python import lrange
 from statsmodels.formula.formulatools import (_remove_intercept_patsy,
                                     _has_intercept, _intercept_idx)
 from statsmodels.iolib import summary2
 
+
 def _get_covariance(model, robust):
     if robust is None:
         return model.cov_params()
     elif robust == "hc0":
-        se = model.HC0_se
         return model.cov_HC0
     elif robust == "hc1":
-        se = model.HC1_se
         return model.cov_HC1
     elif robust == "hc2":
-        se = model.HC2_se
         return model.cov_HC2
     elif robust == "hc3":
-        se = model.HC3_se
         return model.cov_HC3
-    else: # pragma: no cover
+    else:  # pragma: no cover
         raise ValueError("robust options %s not understood" % robust)
 
-#NOTE: these need to take into account weights !
+
+# NOTE: these need to take into account weights !
 
 def anova_single(model, **kwargs):
     """
@@ -73,22 +71,23 @@ def anova_single(model, **kwargs):
     pr_test = "PR(>%s)" % test
     names = ['df', 'sum_sq', 'mean_sq', test, pr_test]
 
-    table = DataFrame(np.zeros((n_rows, 5)), columns = names)
+    table = DataFrame(np.zeros((n_rows, 5)), columns=names)
 
-    if typ in [1,"I"]:
+    if typ in [1, "I"]:
         return anova1_lm_single(model, endog, exog, nobs, design_info, table,
                                 n_rows, test, pr_test, robust)
     elif typ in [2, "II"]:
         return anova2_lm_single(model, design_info, n_rows, test, pr_test,
-                robust)
+                                robust)
     elif typ in [3, "III"]:
         return anova3_lm_single(model, design_info, n_rows, test, pr_test,
-                robust)
+                                robust)
     elif typ in [4, "IV"]:
-        raise NotImplemented("Type IV not yet implemented")
-    else: # pragma: no cover
+        raise NotImplementedError("Type IV not yet implemented")
+    else:  # pragma: no cover
         raise ValueError("Type %s not understood" % str(typ))
 
+
 def anova1_lm_single(model, endog, exog, nobs, design_info, table, n_rows, test,
                      pr_test, robust):
     """
@@ -221,7 +220,7 @@ def anova2_lm_single(model, design_info, n_rows, test, pr_test, robust):
         index.append(term.name())
 
     table.index = Index(index + ['Residual'])
-    table = table.iloc [np.argsort(col_order + [model.model.exog.shape[1]+1])]
+    table = table.iloc[np.argsort(col_order + [model.model.exog.shape[1]+1])]
     # back out sum of squares from f_test
     ssr = table[test] * table['df'] * model.ssr/model.df_resid
     table['sum_sq'] = ssr
@@ -260,7 +259,7 @@ def anova3_lm_single(model, design_info, n_rows, test, pr_test, robust):
         index.append(term.name())
 
     table.index = Index(index + ['Residual'])
-    #NOTE: Don't need to sort because terms are an ordered dict now
+    #NOTE: Do not need to sort because terms are an ordered dict now
     #table = table.iloc[np.argsort(col_order + [model.model.exog.shape[1]+1])]
     # back out sum of squares from f_test
     ssr = table[test] * table['df'] * model.ssr/model.df_resid
@@ -293,12 +292,36 @@ def anova_lm(*args, **kwargs):
     Returns
     -------
     anova : DataFrame
-    A DataFrame containing.
+        When args is a single model, return is DataFrame with columns:
+
+        sum_sq : float64
+            Sum of squares for model terms.
+        df : float64
+            Degrees of freedom for model terms.
+        F : float64
+            F statistic value for significance of adding model terms.
+        PR(>F) : float64
+            P-value for significance of adding model terms.
+
+        When args is multiple models, return is DataFrame with columns:
+
+        df_resid : float64
+            Degrees of freedom of residuals in models.
+        ssr : float64
+            Sum of squares of residuals in models.
+        df_diff : float64
+            Degrees of freedom difference from previous model in args
+        ss_dff : float64
+            Difference in ssr from previous model in args
+        F : float64
+            F statistic comparing to previous model in args
+        PR(>F): float64
+            P-value for significance comparing to previous model in args
 
     Notes
     -----
-    Model statistics are given in the order of args. Models must have
-    been fit using the formula api.
+    Model statistics are given in the order of args. Models must have been fit
+    using the formula api.
 
     See Also
     --------
@@ -308,7 +331,7 @@ def anova_lm(*args, **kwargs):
     --------
     >>> import statsmodels.api as sm
     >>> from statsmodels.formula.api import ols
-    >>> moore = sm.datasets.get_rdataset("Moore", "car", cache=True) # load
+    >>> moore = sm.datasets.get_rdataset("Moore", "carData", cache=True) # load
     >>> data = moore.data
     >>> data = data.rename(columns={"partner.status" :
     ...                             "partner_status"}) # make name pythonic
@@ -325,9 +348,7 @@ def anova_lm(*args, **kwargs):
         model = args[0]
         return anova_single(model, **kwargs)
 
-    try:
-        assert typ in [1,"I"]
-    except:
+    if typ not in [1, "I"]:
         raise ValueError("Multiple models only supported for type I. "
                          "Got type %s" % str(typ))
 
@@ -336,21 +357,21 @@ def anova_lm(*args, **kwargs):
     n_models = len(args)
     pr_test = "Pr(>%s)" % test
     names = ['df_resid', 'ssr', 'df_diff', 'ss_diff', test, pr_test]
-    table = DataFrame(np.zeros((n_models, 6)), columns = names)
+    table = DataFrame(np.zeros((n_models, 6)), columns=names)
 
     if not scale: # assume biggest model is last
         scale = args[-1].scale
 
-    table["ssr"] = lmap(getattr, args, ["ssr"]*n_models)
-    table["df_resid"] = lmap(getattr, args, ["df_resid"]*n_models)
+    table["ssr"] = [mdl.ssr for mdl in args]
+    table["df_resid"] = [mdl.df_resid for mdl in args]
     table.loc[table.index[1:], "df_diff"] = -np.diff(table["df_resid"].values)
     table["ss_diff"] = -table["ssr"].diff()
     if test == "F":
         table["F"] = table["ss_diff"] / table["df_diff"] / scale
         table[pr_test] = stats.f.sf(table["F"], table["df_diff"],
-                             table["df_resid"])
+                                    table["df_resid"])
         # for earlier scipy - stats.f.sf(np.nan, 10, 2) -> 0 not nan
-        table[pr_test][table['F'].isnull()] = np.nan
+        table.loc[table['F'].isnull(), pr_test] = np.nan
 
     return table
 
@@ -388,7 +409,6 @@ def _ssr_reduced_model(y, x, term_slices, params, keys):
         residual sum of squares
     df : int
         degrees of freedom
-
     """
     ind = _not_slice(term_slices, keys, x.shape[1])
     params1 = params[ind]
@@ -398,7 +418,7 @@ def _ssr_reduced_model(y, x, term_slices, params, keys):
     return ssr, df_resid
 
 
-class AnovaRM(object):
+class AnovaRM:
     """
     Repeated measures Anova using least squares regression
 
@@ -413,15 +433,15 @@ class AnovaRM(object):
     Parameters
     ----------
     data : DataFrame
-    depvar : string
+    depvar : str
         The dependent variable in `data`
-    subject : string
+    subject : str
         Specify the subject id
-    within : a list of string(s)
+    within : list[str]
         The within-subject factors
-    between : a list of string(s)
+    between : list[str]
         The between-subject factors, this is not yet implemented
-    aggregate_func : None, 'mean', or function
+    aggregate_func : {None, 'mean', callable}
         If the data set contains more than a single observation per subject
         and cell of the specified model, this function will be used to
         aggregate the data before running the Anova. `None` (the default) will
@@ -431,7 +451,7 @@ class AnovaRM(object):
 
     Returns
     -------
-    results: AnovaResults instance
+    results : AnovaResults instance
 
     Raises
     ------
@@ -452,7 +472,6 @@ class AnovaRM(object):
     References
     ----------
     .. [*] Rutherford, Andrew. Anova and ANCOVA: a GLM approach. John Wiley & Sons, 2011.
-
     """
 
     def __init__(self, data, depvar, subject, within=None, between=None,
@@ -498,7 +517,6 @@ class AnovaRM(object):
         returns None if it is balance
 
         Return might change
-
         """
         factor_levels = 1
         for wi in self.within:
@@ -531,7 +549,6 @@ class AnovaRM(object):
         Returns
         -------
         AnovaResults instance
-
         """
         y = self.data[self.depvar].values
 
@@ -562,8 +579,8 @@ class AnovaRM(object):
         df_resid = results.df_resid
         ssr = results.ssr
 
-        anova_table = pd.DataFrame(
-            {'F Value': [], 'Num DF': [], 'Den DF': [], 'Pr > F': []})
+        columns = ['F Value', 'Num DF', 'Den DF', 'Pr > F']
+        anova_table = pd.DataFrame(np.zeros((0, 4)), columns=columns)
 
         for key in term_slices:
             if self.subject not in key and key != 'Intercept':
@@ -590,10 +607,10 @@ class AnovaRM(object):
                 anova_table.loc[term, 'Den DF'] = df2
                 anova_table.loc[term, 'Pr > F'] = p
 
-        return AnovaResults(anova_table.iloc[:, [1, 2, 0, 3]])
+        return AnovaResults(anova_table)
 
 
-class AnovaResults(object):
+class AnovaResults:
     """
     Anova results class
 
@@ -612,8 +629,7 @@ class AnovaResults(object):
 
         Returns
         -------
-        summary : Summary instance
-
+        summary : summary2.Summary instance
         """
         summ = summary2.Summary()
         summ.add_title('Anova')
@@ -621,15 +637,16 @@ class AnovaResults(object):
 
         return summ
 
+
 if __name__ == "__main__":
     import pandas
     from statsmodels.formula.api import ols
     # in R
     #library(car)
     #write.csv(Moore, "moore.csv", row.names=FALSE)
-    moore = pandas.read_table('moore.csv', delimiter=",", skiprows=1,
-                                names=['partner_status','conformity',
-                                    'fcategory','fscore'])
+    moore = pandas.read_csv('moore.csv', skiprows=1,
+                            names=['partner_status','conformity',
+                                   'fcategory','fscore'])
     moore_lm = ols('conformity ~ C(fcategory, Sum)*C(partner_status, Sum)',
                     data=moore).fit()
 
