@@ -14,8 +14,6 @@ statistic. Some alternative test statistic results have not been verified.
 
 TODO
 * refactor to store intermediate results
-* how easy is it to attach a test that is a class to a result instance,
-  for example CompareCox as a method compare_cox(self, other) ?
 
 missing:
 
@@ -97,7 +95,7 @@ def _check_nested_results(results_x, results_z):
     return nested
 
 
-class ResultsStore(object):
+class ResultsStore:
     def __str__(self):
         return getattr(self, '_str', self.__class__.__name__)
 
@@ -173,41 +171,6 @@ def compare_cox(results_x, results_z, store=False):
     return q, pval
 
 
-class CompareCox(object):
-    """
-    Cox Test for non-nested models
-
-    .. deprecated:: 0.11
-
-       CompareCox is deprecated in favor of compare_cox.
-       CompareCox will be removed after 0.12.
-    """
-
-    def __init__(self):
-        import warnings
-        warnings.warn("CompareCox is deprecated in favor of compare_cox and "
-                      "will be removed after 0.12.", FutureWarning)
-        self.res_dx = self.res_xzx = self.c01 = None
-        self.v01 = self.q = self.pvalue = self.dist = None
-
-    def run(self, results_x, results_z, attach=False):
-        results = compare_cox(results_x, results_z, store=attach)
-        if attach:
-            res = results[-1]
-            self.res_dx = res.res_dx
-            self.res_xzx = res.res_xzx
-            self.c01 = res.c01
-            self.v01 = res.v01
-            self.q = res.q
-            self.pvalue = res.pvalue
-            self.dist = res.dist
-
-        return results
-
-    def __call__(self, results_x, results_z):
-        return self.run(results_x, results_z, attach=False)
-
-
 def compare_j(results_x, results_z, store=False):
     """
     Compute the J-test for non-nested models
@@ -265,37 +228,6 @@ def compare_j(results_x, results_z, store=False):
     return tstat, pval
 
 
-class CompareJ(object):
-    """
-    J-Test for comparing non-nested models
-
-    .. deprecated:: 0.11
-
-       CompareJ is deprecated in favor of compare_j.
-       CompareJ will be removed after 0.12.
-    """
-
-    def __init__(self):
-        import warnings
-        warnings.warn("CompareJ is deprecated in favor of compare_j and will "
-                      "be removed after 0.12.", FutureWarning)
-        self.res_zx = self.dist = self.teststat = self.pvalue = None
-
-    def run(self, results_x, results_z, attach=True):
-        res = compare_j(results_x, results_z, store=attach)
-        tstat, pval = res[:2]
-        if attach:
-            self.res_zx = res[-1].res_zx
-            self.dist = res[-1].dist
-            self.teststat = res[-1].teststat
-            self.pvalue = res[-1].pvalue
-
-        return tstat, pval
-
-    def __call__(self, results_x, results_z):
-        return self.run(results_x, results_z, attach=False)
-
-
 def compare_encompassing(results_x, results_z, cov_type="nonrobust",
                          cov_kwargs=None):
     r"""
@@ -371,8 +303,8 @@ def compare_encompassing(results_x, results_z, cov_type="nonrobust",
         res = OLS(endog, aug_reg).fit(cov_type=cov_est, cov_kwds=cov_kwds)
         r_matrix = np.zeros((k_a, k))
         r_matrix[:, -k_a:] = np.eye(k_a)
-        test = res.wald_test(r_matrix, use_f=True)
-        stat, pvalue = float(np.squeeze(test.statistic)), float(test.pvalue)
+        test = res.wald_test(r_matrix, use_f=True, scalar=True)
+        stat, pvalue = test.statistic, test.pvalue
         df_num, df_denom = int(test.df_num), int(test.df_denom)
         return stat, pvalue, df_num, df_denom
 
@@ -384,7 +316,7 @@ def compare_encompassing(results_x, results_z, cov_type="nonrobust",
 
 
 def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
-                   return_df=None, auto_lag=False):
+                   return_df=True, auto_lag=False):
     """
     Ljung-Box test of autocorrelation in residuals.
 
@@ -399,7 +331,6 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
         length. If lags is a list or array, then all lags are included up to
         the largest lag in the list, however only the tests for the lags in
         the list are reported. If lags is None, then the default maxlag is
-        currently min((nobs // 2 - 2), 40). After 0.12 this will change to
         min(10, nobs // 5). The default number of lags changes if period
         is set.
     boxpierce : bool, default False
@@ -416,31 +347,25 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
         for seasonal data which uses min(2*period, nobs // 5) if set. If None,
         then the default rule is used to set the number of lags. When set, must
         be >= 2.
-    return_df : bool, default None
-        Flag indicating whether to return the result as a single DataFrame
-        with columns lb_stat, lb_pvalue, and optionally bp_stat and bp_pvalue.
-        After 0.12, this will become the only return method.  Set to True
-        to return the DataFrame or False to continue returning the 2 - 4
-        output. If None (the default), a warning is raised.
     auto_lag : bool, default False
         Flag indicating whether to automatically determine the optimal lag
         length based on threshold of maximum correlation value.
 
     Returns
     -------
-    lbvalue : float or array
-        The Ljung-Box test statistic.
-    pvalue : float or array
-        The p-value based on chi-square distribution. The p-value is computed
-        as 1.0 - chi2.cdf(lbvalue, dof) where dof is lag - model_df. If
-        lag - model_df <= 0, then NaN is returned for the pvalue.
-    bpvalue : (optional), float or array
-        The test statistic for Box-Pierce test.
-    bppvalue : (optional), float or array
-        The p-value based for Box-Pierce test on chi-square distribution.
-        The p-value is computed as 1.0 - chi2.cdf(bpvalue, dof) where dof is
-        lag - model_df. If lag - model_df <= 0, then NaN is returned for the
-        pvalue.
+    DataFrame
+        Frame with columns:
+
+        * lb_stat - The Ljung-Box test statistic.
+        * lb_pvalue - The p-value based on chi-square distribution. The
+          p-value is computed as 1 - chi2.cdf(lb_stat, dof) where dof is
+          lag - model_df. If lag - model_df <= 0, then NaN is returned for
+          the pvalue.
+        * bp_stat - The Box-Pierce test statistic.
+        * bp_pvalue - The p-value based for Box-Pierce test on chi-square
+          distribution. The p-value is computed as 1 - chi2.cdf(bp_stat, dof)
+          where dof is lag - model_df. If lag - model_df <= 0, then NaN is
+          returned for the pvalue.
 
     See Also
     --------
@@ -448,6 +373,9 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
         Regression model fitting.
     statsmodels.regression.linear_model.RegressionResults
         Results from linear regression models.
+    statsmodels.stats.stattools.q_stat
+        Ljung-Box test statistic computed from estimated
+        autocorrelations.
 
     Notes
     -----
@@ -471,28 +399,10 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
            lb_stat     lb_pvalue
     10  214.106992  1.827374e-40
     """
-    def get_optimal_length(threshold_metric, threshold, maxlag, func):
-        optimal_lag = 0
-        least_penalised = 0
-
-        for lags in range(1, maxlag + 1):
-            if (threshold_metric <= threshold):
-                penalty = lags * np.log(nobs)
-            else:
-                penalty = 2 * lags
-
-            test_statistic = func(lags)
-            penalised = test_statistic - penalty
-            if (penalised > least_penalised):
-                optimal_lag = lags
-                least_penalised = penalised
-
-        return optimal_lag
     # Avoid cyclic import
     from statsmodels.tsa.stattools import acf
     x = array_like(x, "x")
     period = int_like(period, "period", optional=True)
-    return_df = bool_like(return_df, "return_df", optional=True)
     model_df = int_like(model_df, "model_df", optional=False)
     if period is not None and period <= 1:
         raise ValueError("period must be >= 2")
@@ -502,38 +412,36 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
     if auto_lag:
         maxlag = nobs - 1
 
-        # Compute threshold metrics
+        # Compute sum of squared autocorrelations
         sacf = acf(x, nlags=maxlag, fft=False)
-        sacf2 = sacf[1:maxlag + 1] ** 2 / (nobs - np.arange(1, maxlag + 1))
-        q = 2.4
-        threshold = np.sqrt(q * np.log(nobs))
-        threshold_metric = max(np.abs(sacf)) * np.sqrt(nobs)
 
         if not boxpierce:
-            lags = get_optimal_length(
-                threshold_metric,
-                threshold, maxlag,
-                lambda p: nobs * (nobs + 2) * np.cumsum(sacf2)[p - 1])
+            q_sacf = (nobs * (nobs + 2) *
+                      np.cumsum(sacf[1:maxlag + 1] ** 2
+                                / (nobs - np.arange(1, maxlag + 1))))
         else:
-            lags = get_optimal_length(
-                threshold_metric,
-                threshold,
-                maxlag,
-                lambda p: nobs * np.cumsum(sacf[1:maxlag + 1] ** 2)[p - 1])
+            q_sacf = nobs * np.cumsum(sacf[1:maxlag + 1] ** 2)
 
+        # obtain thresholds
+        q = 2.4
+        threshold = np.sqrt(q * np.log(nobs))
+        threshold_metric = np.abs(sacf).max() * np.sqrt(nobs)
+
+        # compute penalized sum of squared autocorrelations
+        if (threshold_metric <= threshold):
+            q_sacf = q_sacf - (np.arange(1, nobs) * np.log(nobs))
+        else:
+            q_sacf = q_sacf - (2 * np.arange(1, nobs))
+
+        # note: np.argmax returns first (i.e., smallest) index of largest value
+        lags = np.argmax(q_sacf)
+        lags = max(1, lags)  # optimal lag has to be at least 1
         lags = int_like(lags, "lags")
         lags = np.arange(1, lags + 1)
     elif period is not None:
         lags = np.arange(1, min(nobs // 5, 2 * period) + 1, dtype=int)
     elif lags is None:
-        # TODO: Switch to min(10, nobs//5) after 0.12
-        import warnings
-        warnings.warn("The default value of lags is changing.  After 0.12, "
-                      "this value will become min(10, nobs//5). Directly set"
-                      "lags to silence this warning.", FutureWarning)
-        # Future
-        # lags = np.arange(1, min(nobs // 5, 10) + 1, dtype=int)
-        lags = np.arange(1, min((nobs // 2 - 2), 40) + 1, dtype=int)
+        lags = np.arange(1, min(nobs // 5, 10) + 1, dtype=int)
     elif not isinstance(lags, Iterable):
         lags = int_like(lags, "lags")
         lags = np.arange(1, lags + 1)
@@ -550,33 +458,20 @@ def acorr_ljungbox(x, lags=None, boxpierce=False, model_df=0, period=None,
     loc = adj_lags > 0
     pval[loc] = stats.chi2.sf(qljungbox[loc], adj_lags[loc])
 
-    if return_df is None:
-        msg = ("The value returned will change to a single DataFrame after "
-               "0.12 is released.  Set return_df to True to use to return a "
-               "DataFrame now.  Set return_df to False to silence this "
-               "warning.")
-        import warnings
-        warnings.warn(msg, FutureWarning)
-
     if not boxpierce:
-        if return_df:
-            return pd.DataFrame({"lb_stat": qljungbox, "lb_pvalue": pval},
-                                index=lags)
-        return qljungbox, pval
+        return pd.DataFrame({"lb_stat": qljungbox, "lb_pvalue": pval},
+                            index=lags)
 
     qboxpierce = nobs * np.cumsum(sacf[1:maxlag + 1] ** 2)[lags - 1]
     pvalbp = np.full_like(qljungbox, np.nan)
     pvalbp[loc] = stats.chi2.sf(qboxpierce[loc], adj_lags[loc])
-    if return_df:
-        return pd.DataFrame({"lb_stat": qljungbox, "lb_pvalue": pval,
-                             "bp_stat": qboxpierce, "bp_pvalue": pvalbp},
-                            index=lags)
-
-    return qljungbox, pval, qboxpierce, pvalbp
+    return pd.DataFrame({"lb_stat": qljungbox, "lb_pvalue": pval,
+                         "bp_stat": qboxpierce, "bp_pvalue": pvalbp},
+                        index=lags)
 
 
 @deprecate_kwarg("maxlag", "nlags")
-def acorr_lm(resid, nlags=None, autolag="AIC", store=False, *, period=None,
+def acorr_lm(resid, nlags=None, store=False, *, period=None,
              ddof=0, cov_type="nonrobust", cov_kwargs=None):
     """
     Lagrange Multiplier tests for autocorrelation.
@@ -590,12 +485,7 @@ def acorr_lm(resid, nlags=None, autolag="AIC", store=False, *, period=None,
     resid : array_like
         Time series to test.
     nlags : int, default None
-        Highest lag to use. The behavior of this parameter will change
-        after 0.12.
-    autolag : {str, None}, default "AIC"
-        If None, then a fixed number of lags given by maxlag is used. This
-        parameter is deprecated and will be removed after 0.12.  Searching
-        for model specification cannot control test size.
+        Highest lag to use.
     store : bool, default False
         If true then the intermediate results are also returned.
     period : int, default none
@@ -652,16 +542,7 @@ def acorr_lm(resid, nlags=None, autolag="AIC", store=False, *, period=None,
     if period is not None and nlags is None:
         maxlag = min(nobs // 5, 2 * period)
     elif nlags is None:
-        # TODO: Switch to min(10, nobs//5) after 0.12
-        import warnings
-        warnings.warn("The default value of nlags is changing.  After 0.12, "
-                      "this value will become min(10, nobs//5). Directly set"
-                      "maxlags or period to silence this warning.",
-                      FutureWarning)
-        # Future
-        # maxlag = min(nobs // 5, 10)
-        # Old: for adf from Greene referencing Schwert 1989
-        maxlag = int(np.ceil(12. * np.power(nobs / 100., 1 / 4.)))
+        maxlag = min(10, nobs // 5)
     else:
         maxlag = nlags
 
@@ -670,52 +551,21 @@ def acorr_lm(resid, nlags=None, autolag="AIC", store=False, *, period=None,
     xdall = np.c_[np.ones((nobs, 1)), xdall]
     xshort = resid[-nobs:]
     res_store = ResultsStore()
-
-    if autolag:
-        # TODO: Deprecate this
-        #   Use same rules as autocorr
-        # search for lag length with highest information criteria
-        # Note: I use the same number of observations to have comparable IC
-        import warnings
-        warnings.warn("autolag is deprecated and will be removed after 0.12. "
-                      "Model selection before testing fails to control test "
-                      "size. Set autolag to False to silence this warning.",
-                      FutureWarning)
-        results = {}
-        for mlag in range(1, maxlag + 1):
-            results[mlag] = OLS(xshort, xdall[:, :mlag + 1]).fit()
-
-        if autolag.lower() == "aic":
-            bestic, icbestlag = min((v.aic, k) for k, v in results.items())
-        elif autolag.lower() == "bic":
-            icbest, icbestlag = min((v.bic, k) for k, v in results.items())
-        else:
-            raise ValueError("autolag can only be None, \"AIC\" or \"BIC\"")
-
-        # rerun ols with best ic
-        xdall = lagmat(resid[:, None], icbestlag, trim="both")
-        nobs = xdall.shape[0]
-        xdall = np.c_[np.ones((nobs, 1)), xdall]
-        xshort = resid[-nobs:]
-        usedlag = icbestlag
-        if store:
-            res_store.results = results
-    else:
-        usedlag = maxlag
+    usedlag = maxlag
 
     resols = OLS(xshort, xdall[:, :usedlag + 1]).fit(cov_type=cov_type,
                                                      cov_kwargs=cov_kwargs)
-    fval = resols.fvalue
-    fpval = resols.f_pvalue
+    fval = float(resols.fvalue)
+    fpval = float(resols.f_pvalue)
     if cov_type == "nonrobust":
         lm = (nobs - ddof) * resols.rsquared
         lmpval = stats.chi2.sf(lm, usedlag)
         # Note: deg of freedom for LM test: nvars - constant = lags used
     else:
-        r_matrix = np.hstack((np.ones((usedlag, 1)), np.eye(usedlag)))
-        test_stat = resols.wald_test(r_matrix, use_f=False)
+        r_matrix = np.hstack((np.zeros((usedlag, 1)), np.eye(usedlag)))
+        test_stat = resols.wald_test(r_matrix, use_f=False, scalar=True)
         lm = float(test_stat.statistic)
-        lmpval = test_stat.pvalue
+        lmpval = float(test_stat.pvalue)
 
     if store:
         res_store.resols = resols
@@ -726,7 +576,7 @@ def acorr_lm(resid, nlags=None, autolag="AIC", store=False, *, period=None,
 
 
 @deprecate_kwarg("maxlag", "nlags")
-def het_arch(resid, nlags=None, autolag=None, store=False, ddof=0):
+def het_arch(resid, nlags=None, store=False, ddof=0):
     """
     Engle's Test for Autoregressive Conditional Heteroscedasticity (ARCH).
 
@@ -735,12 +585,7 @@ def het_arch(resid, nlags=None, autolag=None, store=False, ddof=0):
     resid : ndarray
         residuals from an estimation, or time series
     nlags : int, default None
-        Highest lag to use. The behavior of this parameter will change
-        after 0.12.
-    autolag : {str, None}, default None
-        If None, then a fixed number of lags given by maxlag is used. This
-        parameter is deprecated and will be removed after 0.12.  Searching
-        for model specification cannot control test size.
+        Highest lag to use.
     store : bool, default False
         If true then the intermediate results are also returned
     ddof : int, default 0
@@ -767,8 +612,7 @@ def het_arch(resid, nlags=None, autolag=None, store=False, ddof=0):
     -----
     verified against R:FinTS::ArchTest
     """
-    return acorr_lm(resid ** 2, nlags=nlags, autolag=autolag, store=store,
-                    ddof=ddof)
+    return acorr_lm(resid ** 2, nlags=nlags, store=store, ddof=ddof)
 
 
 @deprecate_kwarg("results", "res")
@@ -781,7 +625,7 @@ def acorr_breusch_godfrey(res, nlags=None, store=False):
     res : RegressionResults
         Estimation results for which the residuals are tested for serial
         correlation.
-    nlags : int, default None
+    nlags : int, optional
         Number of lags to include in the auxiliary regression. (nlags is
         highest lag).
     store : bool, default False
@@ -821,15 +665,7 @@ def acorr_breusch_godfrey(res, nlags=None, store=False):
     exog_old = res.model.exog
     nobs = x.shape[0]
     if nlags is None:
-        # TODO: Switch to min(10, nobs//5) after 0.12
-        import warnings
-        warnings.warn("The default value of nlags is changing.  After 0.12, "
-                      "this value will become min(10, nobs//5). Directly set"
-                      "nlags or period to silence this warning.",
-                      FutureWarning)
-
-        nlags = np.trunc(12. * np.power(nobs / 100., 1 / 4.))
-        nlags = int(nlags)
+        nlags = min(10, nobs // 5)
 
     x = np.concatenate((np.zeros(nlags), x))
 
@@ -837,7 +673,10 @@ def acorr_breusch_godfrey(res, nlags=None, store=False):
     nobs = xdall.shape[0]
     xdall = np.c_[np.ones((nobs, 1)), xdall]
     xshort = x[-nobs:]
-    exog = np.column_stack((exog_old, xdall))
+    if exog_old is None:
+        exog = xdall
+    else:
+        exog = np.column_stack((exog_old, xdall))
     k_vars = exog.shape[1]
 
     resols = OLS(xshort, exog).fit()
@@ -859,6 +698,28 @@ def acorr_breusch_godfrey(res, nlags=None, store=False):
         return lm, lmpval, fval, fpval
 
 
+def _check_het_test(x: np.ndarray, test_name: str) -> None:
+    """
+    Check validity of the exogenous regressors in a heteroskedasticity test
+
+    Parameters
+    ----------
+    x : ndarray
+        The exogenous regressor array
+    test_name : str
+        The test name for the exception
+    """
+    x_max = x.max(axis=0)
+    if (
+        not np.any(((x_max - x.min(axis=0)) == 0) & (x_max != 0))
+        or x.shape[1] < 2
+    ):
+        raise ValueError(
+            f"{test_name} test requires exog to have at least "
+            "two columns where one is a constant."
+        )
+
+
 def het_breuschpagan(resid, exog_het, robust=True):
     r"""
     Breusch-Pagan Lagrange Multiplier test for heteroscedasticity
@@ -927,9 +788,9 @@ def het_breuschpagan(resid, exog_het, robust=True):
     .. [3] Koenker, R. (1981). "A note on studentizing a test for
        heteroskedasticity". Journal of Econometrics 17 (1): 107–112.
     """
-
-    x = np.asarray(exog_het)
-    y = np.asarray(resid) ** 2
+    x = array_like(exog_het, "exog_het", ndim=2)
+    _check_het_test(x, "The Breusch-Pagan")
+    y = array_like(resid, "resid", ndim=1) ** 2
     if not robust:
         y = y / np.mean(y)
     nobs, nvars = x.shape
@@ -980,9 +841,7 @@ def het_white(resid, exog):
     """
     x = array_like(exog, "exog", ndim=2)
     y = array_like(resid, "resid", ndim=2, shape=(x.shape[0], 1))
-    if x.shape[1] < 2:
-        raise ValueError("White's heteroskedasticity test requires exog to"
-                         "have at least two columns where one is a constant.")
+    _check_het_test(x, "White's heteroskedasticity")
     nobs, nvars0 = x.shape
     i0, i1 = np.triu_indices(nvars0)
     exog = x[:, i0] * x[:, i1]
@@ -1117,63 +976,6 @@ F-statistic =%8.4f and p-value =%8.4f""" % (ordering, fval, fpval)
     return fval, fpval, ordering
 
 
-class HetGoldfeldQuandt(object):
-    """
-    Test whether variance is the same in 2 subsamples
-
-    .. deprecated:: 0.11
-
-       HetGoldfeldQuandt is deprecated in favor of het_goldfeldquandt.
-       HetGoldfeldQuandt will be removed after 0.12.
-
-    See Also
-    --------
-    het_goldfeldquant
-        Goldfeld-Quant heteroskedasticity test.
-    """
-
-    def __init__(self):
-        import warnings
-        warnings.warn("HetGoldfeldQuandt is deprecated in favor of"
-                      "het_goldfeldquandt. HetGoldfeldQuandt will be removed"
-                      "after 0.12.",
-                      FutureWarning)
-        self.fval = self.fpval = self.df_fval = self.resols1 = None
-        self.resols2 = self.ordering = self.split = self._str = None
-
-    def run(self, y, x, idx=None, split=None, drop=None,
-            alternative="increasing", attach=True):
-        """
-        .. deprecated:: 0.11
-
-           Use het_goldfeldquant instead.
-
-        See Also
-        --------
-        het_goldfeldquant
-            Goldfeld-Quant heteroskedasticity test.
-        """
-        res = het_goldfeldquandt(y, x, idx=idx, split=split, drop=drop,
-                                 alternative=alternative, store=attach)
-        if attach:
-            store = res[-1]
-            self.__doc__ = store.__doc__
-            self.fval = store.fval
-            self.fpval = store.fpval
-            self.df_fval = store.df_fval
-            self.resols1 = store.resols1
-            self.resols2 = store.resols2
-            self.ordering = store.ordering
-            self.split = store.split
-
-        return res[:3]
-
-    def __call__(self, y, x, idx=None, split=None, drop=None,
-                 alternative="increasing"):
-        return self.run(y, x, idx=idx, split=split, drop=drop,
-                        attach=False, alternative=alternative)
-
-
 @deprecate_kwarg("result", "res")
 def linear_reset(res, power=3, test_type="fitted", use_f=False,
                  cov_type="nonrobust", cov_kwargs=None):
@@ -1287,7 +1089,7 @@ def linear_reset(res, power=3, test_type="fitted", use_f=False,
     nrestr = aug_exog.shape[1] - exog.shape[1]
     nparams = aug_exog.shape[1]
     r_mat = np.eye(nrestr, nparams, k=nparams-nrestr)
-    return res.wald_test(r_mat, use_f=use_f)
+    return res.wald_test(r_mat, use_f=use_f, scalar=True)
 
 
 def linear_harvey_collier(res, order_by=None, skip=None):
@@ -1636,6 +1438,8 @@ def recursive_olsresiduals(res, skip=None, lamda=0.0, alpha=0.95,
     Journal of the Royal Statistical Society. Series B (Methodological) 37,
     no. 2 (1975): 149-192.
     """
+    if not isinstance(res, RegressionResultsWrapper):
+        raise TypeError("res a regression results instance")
     y = res.model.endog
     x = res.model.exog
     order_by = array_like(order_by, "order_by", dtype="int", optional=True,
@@ -1676,9 +1480,9 @@ skip large enough to ensure that the first OLS estimator is well-defined.
 
         # get prediction error with previous beta
         yipred = np.dot(xi, beta)
-        rypred[i] = yipred
+        rypred[i] = np.squeeze(yipred)
         residi = yi - yipred
-        rresid[i] = residi
+        rresid[i] = np.squeeze(residi)
 
         # update beta and inverse(X'X)
         tmp = np.dot(xtxi, xi.T)
@@ -1688,7 +1492,7 @@ skip large enough to ensure that the first OLS estimator is well-defined.
 
         beta = beta + (tmp * residi / ft).ravel()  # BigJudge equ 5.5.14
         rparams[i] = beta
-        rvarraw[i] = ft
+        rvarraw[i] = np.squeeze(ft)
 
     rresid_scaled = rresid / np.sqrt(rvarraw)  # N(0,sigma2) distributed
     nrr = nobs - skip
@@ -1757,7 +1561,7 @@ def breaks_hansen(olsresults):
     f = nobs * (ft[:, :, None] * ft[:, None, :]).sum(0)
     s = (score[:, :, None] * score[:, None, :]).sum(0)
     h = np.trace(np.dot(np.linalg.inv(f), s))
-    crit95 = np.array([(2, 1.9), (6, 3.75), (15, 3.75), (19, 4.52)],
+    crit95 = np.array([(2, 1.01), (6, 1.9), (15, 3.75), (19, 4.52)],
                       dtype=[("nobs", int), ("crit", float)])
     # TODO: get critical values from Bruce Hansen's 1992 paper
     return h, crit95
