@@ -11,6 +11,9 @@ import numpy as np
 from scipy import stats
 from scipy.special import ncfdtrinc
 
+# functions that use scipy.special instead of boost based function in stats
+from statsmodels.stats.power import ncf_cdf, ncf_ppf
+
 from statsmodels.stats.robust_compare import TrimmedMean, scale_transform
 from statsmodels.tools.testing import Holder
 from statsmodels.stats.base import HolderTuple
@@ -180,7 +183,7 @@ def effectsize_oneway(means, vars_, nobs, use_var="unequal", ddof_between=0):
 
 
 def convert_effectsize_fsqu(f2=None, eta2=None):
-    """convert squared effect sizes in f family
+    """Convert squared effect sizes in f family
 
     f2 is signal to noise ratio, var_explained / var_residual
 
@@ -455,7 +458,7 @@ def confint_effectsize_oneway(f_stat, df, alpha=0.05, nobs=None):
 def anova_generic(means, variances, nobs, use_var="unequal",
                   welch_correction=True, info=None):
     """
-    Oneway anova based on summary statistics
+    Oneway Anova based on summary statistics
 
     Parameters
     ----------
@@ -558,7 +561,7 @@ def anova_generic(means, variances, nobs, use_var="unequal",
 
 def anova_oneway(data, groups=None, use_var="unequal", welch_correction=True,
                  trim_frac=0):
-    """oneway anova
+    """Oneway Anova
 
     This implements standard anova, Welch and Brown-Forsythe, and trimmed
     (Yuen) variants of those.
@@ -774,7 +777,7 @@ def equivalence_oneway_generic(f_stat, n_groups, nobs, equiv_margin, df,
         type_effectsize = "Cohen's f_squared"
     else:
         raise ValueError('`margin_type` should be "f2" or "wellek"')
-    crit_f = stats.ncf.ppf(alpha, df[0], df[1], nc_null)
+    crit_f = ncf_ppf(alpha, df[0], df[1], nc_null)
 
     if margin_type == "wellek":
         # TODO: do we need a sqrt
@@ -784,8 +787,8 @@ def equivalence_oneway_generic(f_stat, n_groups, nobs, equiv_margin, df,
 
     reject = (es < crit_es)
 
-    pv = stats.ncf.cdf(f_stat, df[0], df[1], nc_null)
-    pwr = stats.ncf.cdf(crit_f, df[0], df[1], 1e-13)  # scipy, cannot be 0
+    pv = ncf_cdf(f_stat, df[0], df[1], nc_null)
+    pwr = ncf_cdf(crit_f, df[0], df[1], 1e-13)  # scipy, cannot be 0
     res = HolderTuple(statistic=f_stat,
                       pvalue=pv,
                       effectsize=es,  # match es type to margin_type
@@ -862,6 +865,10 @@ def equivalence_oneway(data, equiv_margin, groups=None, use_var="unequal",
         The two main attributes are test statistic `statistic` and p-value
         `pvalue`.
 
+    See Also
+    --------
+    anova_oneway
+    equivalence_scale_oneway
     """
 
     # use anova to compute summary statistics and f-statistic
@@ -877,7 +884,7 @@ def equivalence_oneway(data, equiv_margin, groups=None, use_var="unequal",
 
 
 def _power_equivalence_oneway_emp(f_stat, n_groups, nobs, eps, df, alpha=0.05):
-    """empirical power of oneway equivalence test
+    """Empirical power of oneway equivalence test
 
     This only returns post-hoc, empirical power.
 
@@ -912,7 +919,7 @@ def _power_equivalence_oneway_emp(f_stat, n_groups, nobs, eps, df, alpha=0.05):
     nobs_mean = nobs.sum() / n_groups
     fn = f_stat  # post-hoc power, empirical power at estimate
     esn = fn * (n_groups - 1) / nobs_mean  # Wellek psi
-    pow_ = stats.ncf.cdf(res.crit_f, df[0], df[1], nobs_mean * esn)
+    pow_ = ncf_cdf(res.crit_f, df[0], df[1], nobs_mean * esn)
 
     return pow_
 
@@ -976,8 +983,8 @@ def power_equivalence_oneway(f2_alt, equiv_margin, nobs_t, n_groups=None,
     else:
         raise ValueError('`margin_type` should be "f2" or "wellek"')
 
-    crit_f_margin = stats.ncf.ppf(alpha, df[0], df[1], nobs_t * f2_null)
-    pwr_alt = stats.ncf.cdf(crit_f_margin, df[0], df[1], nobs_t * f2_alt)
+    crit_f_margin = ncf_ppf(alpha, df[0], df[1], nobs_t * f2_null)
+    pwr_alt = ncf_cdf(crit_f_margin, df[0], df[1], nobs_t * f2_alt)
     return pwr_alt
 
 
@@ -1148,6 +1155,60 @@ def equivalence_scale_oneway(data, equiv_margin, method='bf', center='median',
     absolute deviation are not scaled to correspond to the variance under
     normal distribution.
 
+    Parameters
+    ----------
+    data : tuple of array_like or DataFrame or Series
+        Data for k independent samples, with k >= 2. The data can be provided
+        as a tuple or list of arrays or in long format with outcome
+        observations in ``data`` and group membership in ``groups``.
+    equiv_margin : float
+        Equivalence margin in terms of effect size. Effect size can be chosen
+        with `margin_type`. default is squared Cohen's f.
+    method : {"unequal", "equal" or "bf"}
+        How to treat heteroscedasticity across samples. This is used as
+        `use_var` option in `anova_oneway` and refers to the variance of the
+        transformed data, i.e. assumption is on 4th moment if squares are used
+        as transform.
+        Three approaches are available:
+
+        "unequal" : Variances are not assumed to be equal across samples.
+            Heteroscedasticity is taken into account with Welch Anova and
+            Satterthwaite-Welch degrees of freedom.
+            This is the default.
+        "equal" : Variances are assumed to be equal across samples.
+            This is the standard Anova.
+        "bf" : Variances are not assumed to be equal across samples.
+            The method is Browne-Forsythe (1971) for testing equality of means
+            with the corrected degrees of freedom by Merothra. The original BF
+            degrees of freedom are available as additional attributes in the
+            results instance, ``df_denom2`` and ``p_value2``.
+    center : "median", "mean", "trimmed" or float
+        Statistic used for centering observations. If a float, then this
+        value is used to center. Default is median.
+    transform : "abs", "square" or callable
+        Transformation for the centered observations. If a callable, then this
+        function is called on the centered data.
+        Default is absolute value.
+    trim_frac_mean : float in [0, 0.5)
+        Trim fraction for the trimmed mean when `center` is "trimmed"
+    trim_frac_anova : float in [0, 0.5)
+        Optional trimming for Anova with trimmed mean and Winsorized variances.
+        With the default trim_frac equal to zero, the oneway Anova statistics
+        are computed without trimming. If `trim_frac` is larger than zero,
+        then the largest and smallest observations in each sample are trimmed.
+        see ``trim_frac`` option in `anova_oneway`
+
+    Returns
+    -------
+    results : instance of HolderTuple class
+        The two main attributes are test statistic `statistic` and p-value
+        `pvalue`.
+
+    See Also
+    --------
+    anova_oneway
+    scale_transform
+    equivalence_oneway
     """
     data = map(np.asarray, data)
     xxd = [scale_transform(x, center=center, transform=transform,
