@@ -168,7 +168,7 @@ def get_thsd(mci, alpha=0.05):
     assert_almost_equal(var_, var2, decimal=14)
     return resi
 
-class CheckTuckeyHSDMixin(object):
+class CheckTuckeyHSDMixin:
 
     @classmethod
     def setup_class_(cls):
@@ -258,11 +258,14 @@ class TestTuckeyHSD2Pandas(TestTuckeyHSD2):
 
     def test_incorrect_output(self):
         # too few groups
-        assert_raises(ValueError, MultiComparison, np.array([1] * 10), [1, 2] * 4)
+        with pytest.raises(ValueError):
+            MultiComparison(np.array([1] * 10), [1, 2] * 4)
         # too many groups
-        assert_raises(ValueError, MultiComparison, np.array([1] * 10), [1, 2] * 6)
+        with pytest.raises(ValueError):
+            MultiComparison(np.array([1] * 10), [1, 2] * 6)
         # just one group
-        assert_raises(ValueError, MultiComparison, np.array([1] * 10), [1] * 10)
+        with pytest.raises(ValueError):
+            MultiComparison(np.array([1] * 10), [1] * 10)
 
         # group_order does not select all observations, only one group left
         with warnings.catch_warnings(record=True) as w:
@@ -362,4 +365,4 @@ class TestTuckeyHSD4(CheckTuckeyHSDMixin):
         cls.reject2 = np.array([False, False, False,  True, False, False,  True, False,  True, False])
 
     def test_hochberg_intervals(self):
-        assert_almost_equal(self.res.halfwidths, self.halfwidth2, 14)
+        assert_almost_equal(self.res.halfwidths, self.halfwidth2, 4)
