@@ -1,10 +1,6 @@
 import subprocess
 import sys
 
-import pytest
-
-from statsmodels.compat.scipy import SCIPY_11
-
 
 def test_lazy_imports():
     # Check that when statsmodels.api is imported, matplotlib is _not_ imported
@@ -19,9 +15,8 @@ def test_lazy_imports():
     assert rc == 0
 
 
-@pytest.mark.skipif(SCIPY_11, reason='SciPy raises on -OO')
 def test_docstring_optimization_compat():
-    # GH#5235 check that importing with stripped docstrings doesn't raise
+    # GH#5235 check that importing with stripped docstrings does not raise
     cmd = sys.executable + ' -OO -c "import statsmodels.api as sm"'
     p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE)
