@@ -1,9 +1,4 @@
-from statsmodels.compat.pandas import (
-    Appender,
-    NumericIndex,
-    is_int_index,
-    to_numpy,
-)
+from statsmodels.compat.pandas import Appender, is_int_index, to_numpy
 
 from abc import ABC, abstractmethod
 import datetime as dt
@@ -121,7 +116,7 @@ class DeterministicTerm(ABC):
             assert isinstance(forecast_index, pd.Index)
             if forecast_index.shape[0] != steps:
                 raise ValueError(
-                    f"The number of values in forecast_index "
+                    "The number of values in forecast_index "
                     f"({forecast_index.shape[0]}) must match steps ({steps})."
                 )
             return forecast_index
@@ -145,16 +140,17 @@ class DeterministicTerm(ABC):
             return pd.RangeIndex(start, stop, step=step)
         elif is_int_index(index) and np.all(np.diff(index) == 1):
             idx_arr = np.arange(index[-1] + 1, index[-1] + steps + 1)
-            return NumericIndex(idx_arr)
+            return pd.Index(idx_arr)
         # default range index
         import warnings
 
         warnings.warn(
             "Only PeriodIndexes, DatetimeIndexes with a frequency set, "
-            "RangesIndexes, and NumericIndex with a unit increment support "
+            "RangesIndexes, and Index with a unit increment support "
             "extending. The index is set will contain the position relative "
             "to the data length.",
             UserWarning,
+            stacklevel=2,
         )
         nobs = index.shape[0]
         return pd.RangeIndex(nobs + 1, nobs + steps + 1)
@@ -175,6 +171,7 @@ class DeterministicTerm(ABC):
 
 class TimeTrendDeterministicTerm(DeterministicTerm, ABC):
     """Abstract Base Class for all Time Trend Deterministic Terms"""
+
     def __init__(self, constant: bool = True, order: int = 0) -> None:
         self._constant = bool_like(constant, "constant")
         self._order = required_int_like(order, "order")
@@ -448,6 +445,7 @@ class Seasonality(DeterministicTerm):
 
 class FourierDeterministicTerm(DeterministicTerm, ABC):
     """Abstract Base Class for all Fourier Deterministic Terms"""
+
     def __init__(self, order: int) -> None:
         self._order = required_int_like(order, "terms")
 
@@ -1093,6 +1091,11 @@ class DeterministicProcess:
     CalendarSeasonality
     CalendarFourier
 
+    Notes
+    -----
+    See the notebook `Deterministic Terms in Time Series Models
+    <../examples/notebooks/generated/deterministics.html>`__ for an overview.
+
     Examples
     --------
     >>> from statsmodels.tsa.deterministic import DeterministicProcess
@@ -1172,9 +1175,9 @@ class DeterministicProcess:
             self._deterministic_terms.append(TimeTrend(constant, order))
         if seasonal and fourier:
             raise ValueError(
-                """seasonal and fourier can be initialized through the constructor since\
-these will be necessarily perfectly collinear. Instead, you can pass \
-additional components using the additional_terms input."""
+                """seasonal and fourier can be initialized through the \
+constructor since these will be necessarily perfectly collinear. Instead, \
+you can pass additional components using the additional_terms input."""
             )
         if (seasonal or fourier) and period is None:
             if period is None:
@@ -1307,7 +1310,8 @@ additional components using the additional_terms input."""
         return terms
 
     def _extend_time_index(
-        self, stop: pd.Timestamp,
+        self,
+        stop: pd.Timestamp,
     ) -> Union[pd.DatetimeIndex, pd.PeriodIndex]:
         index = self._index
         if isinstance(index, pd.PeriodIndex):
@@ -1320,14 +1324,10 @@ additional components using the additional_terms input."""
         assert isinstance(index, pd.RangeIndex) or is_int64_index
         if start < index[0]:
             raise ValueError(START_BEFORE_INDEX_ERR)
-        if is_int64_index:
-            idx_step = 1
+        if isinstance(index, pd.RangeIndex):
+            idx_step = index.step
         else:
-            try:
-                idx_step = index.step
-            except AttributeError:
-                # TODO: Remove after pandas min ver is 1.0.0+
-                idx_step = index[-1] - index[-2] if len(index) > 1 else 1
+            idx_step = np.diff(index).max() if len(index) > 1 else 1
         if idx_step != 1 and ((start - index[0]) % idx_step) != 0:
             raise ValueError(
                 f"The step of the index is not 1 (actual step={idx_step})."
@@ -1335,7 +1335,7 @@ additional components using the additional_terms input."""
                 "generated by the index."
             )
         if is_int64_index:
-            new_idx = NumericIndex(np.arange(start, stop))
+            new_idx = pd.Index(np.arange(start, stop))
         else:
             new_idx = pd.RangeIndex(start, stop, step=idx_step)
         if new_idx[-1] <= self._index[-1]:
@@ -1424,8 +1424,8 @@ additional components using the additional_terms input."""
             raise TypeError(
                 """The index in the deterministic process does not \
 support extension. Only PeriodIndex, DatetimeIndex with a frequency, \
-RangeIndex, and NumericIndex that start at 0 and have only unit differences \
-can be extended when producing out-of-sample forecasts.
+RangeIndex, and integral Indexes that start at 0 and have only unit \
+differences can be extended when producing out-of-sample forecasts.
 """
             )
         if type(self._index) in (pd.RangeIndex,) or is_int_index(self._index):
@@ -1457,3 +1457,29 @@ can be extended when producing out-of-sample forecasts.
             self._extendable = self._index[0] == 0 and np.all(
                 np.diff(self._index) == 1
             )
+
+    def apply(self, index):
+        """
+        Create an identical determinstic process with a different index
+
+        Parameters
+        ----------
+        index : index_like
+            An index-like object. If not an index, it is converted to an
+            index.
+
+        Returns
+        -------
+        DeterministicProcess
+            The deterministic process applied to a different index
+        """
+        return DeterministicProcess(
+            index,
+            period=self._period,
+            constant=self._constant,
+            order=self._order,
+            seasonal=self._seasonal,
+            fourier=self._fourier,
+            additional_terms=self._additional_terms,
+            drop=self._drop,
+        )
