@@ -146,7 +146,8 @@ import datetime as dt
 
 import numpy as np
 import pandas as pd
-from scipy.stats import _distn_infrastructure, norm, rv_continuous, rv_discrete
+from scipy.stats import norm, rv_continuous, rv_discrete
+from scipy.stats.distributions import rv_frozen
 
 from statsmodels.base.covtype import descriptions
 import statsmodels.base.wrapper as wrap
@@ -165,6 +166,7 @@ import statsmodels.tsa.base.tsa_model as tsbase
 from statsmodels.tsa.exponential_smoothing import base
 import statsmodels.tsa.exponential_smoothing._ets_smooth as smooth
 from statsmodels.tsa.exponential_smoothing.initialization import (
+    _initialization_simple,
     _initialization_heuristic,
 )
 from statsmodels.tsa.tsatools import freq_to_period
@@ -470,7 +472,7 @@ class ETSModel(base.StateSpaceMLEModel):
             or self.seasonal == "mul"
         ):
             raise ValueError(
-                "endog must be strictly positive when using"
+                "endog must be strictly positive when using "
                 "multiplicative error, trend or seasonal components."
             )
         if self.damped_trend and not self.has_trend:
@@ -561,10 +563,7 @@ class ETSModel(base.StateSpaceMLEModel):
                     " for models with a seasonal component when"
                     ' initialization method is set to "known".'
                 )
-        elif (
-            self.initialization_method == "heuristic"
-            or self.initialization_method == "estimated"
-        ):
+        elif self.initialization_method == "heuristic":
             (
                 initial_level,
                 initial_trend,
@@ -575,6 +574,29 @@ class ETSModel(base.StateSpaceMLEModel):
                 seasonal=self.seasonal,
                 seasonal_periods=self.seasonal_periods,
             )
+        elif self.initialization_method == "estimated":
+            if self.nobs < 10 + 2 * (self.seasonal_periods // 2):
+                (
+                    initial_level,
+                    initial_trend,
+                    initial_seasonal,
+                ) = _initialization_simple(
+                    self.endog,
+                    trend=self.trend,
+                    seasonal=self.seasonal,
+                    seasonal_periods=self.seasonal_periods,
+                )
+            else:
+                (
+                    initial_level,
+                    initial_trend,
+                    initial_seasonal,
+                ) = _initialization_heuristic(
+                    self.endog,
+                    trend=self.trend,
+                    seasonal=self.seasonal,
+                    seasonal_periods=self.seasonal_periods,
+                )
         if not self.has_trend:
             initial_trend = 0
         if not self.has_seasonal:
@@ -633,6 +655,8 @@ class ETSModel(base.StateSpaceMLEModel):
         endog = np.array(data.orig_endog, order="C")
         if endog.ndim != 1:
             raise ValueError("endog must be 1-dimensional")
+        if endog.dtype != np.double:
+            endog = np.asarray(data.orig_endog, order="C", dtype=float)
         return endog, None
 
     @property
@@ -768,7 +792,11 @@ class ETSModel(base.StateSpaceMLEModel):
         if self.initialization_method != "estimated":
             internal[4] = self.initial_level
             internal[5] = self.initial_trend
-            internal[6:] = self.initial_seasonal
+            if np.isscalar(self.initial_seasonal):
+                internal[6:] = self.initial_seasonal
+            else:
+                # See GH 7893
+                internal[6:] = self.initial_seasonal[::-1]
         return internal
 
     def _model_params(self, internal):
@@ -1132,9 +1160,13 @@ class ETSModel(base.StateSpaceMLEModel):
         res = self._residuals(yhat, data=data)
         logL = -self.nobs / 2 * (np.log(2 * np.pi * np.mean(res ** 2)) + 1)
         if self.error == "mul":
+            # GH-7331: in some cases, yhat can become negative, so that a
+            # multiplicative model is no longer well-defined. To avoid these
+            # parameterizations, we clip negative values to very small positive
+            # values so that the log-transformation yields very large negative
+            # values.
+            yhat[yhat <= 0] = 1 / (1e-8 * (1 + np.abs(yhat[yhat <= 0])))
             logL -= np.sum(np.log(yhat))
-            if np.isnan(logL):
-                logL = np.inf
         return logL
 
     @contextlib.contextmanager
@@ -1169,7 +1201,7 @@ class ETSModel(base.StateSpaceMLEModel):
 
         .. math::
 
-           s^2 = \frac{1}{n}\sum\limits_{t=1}^n \frac{\hat{y}_t - y_t}{k_t}
+           s^2 = \frac{1}{n}\sum\limits_{t=1}^n \frac{(\hat{y}_t - y_t)^2}{k_t}
 
         where :math:`k_t = 1` for the additive error model and :math:`k_t =
         y_t` for the multiplicative error model.
@@ -1382,7 +1414,8 @@ class ETSResults(base.StateSpaceMLEResults):
             self.smoothing_trend = self.beta
         if self.has_seasonal:
             self.season = states[:, self.model._seasonal_index]
-            self.initial_seasonal = internal_params[6:]
+            # See GH 7893
+            self.initial_seasonal = internal_params[6:][::-1]
             self.initial_state[
                 self.model._seasonal_index :
             ] = self.initial_seasonal
@@ -1732,7 +1765,6 @@ class ETSResults(base.StateSpaceMLEResults):
            principles and practice*, 2nd edition, OTexts: Melbourne,
            Australia. OTexts.com/fpp2. Accessed on February 28th 2020.
         """
-
         # Get the starting location
         start_idx = self._get_prediction_start_index(anchor)
 
@@ -1789,7 +1821,7 @@ class ETSResults(base.StateSpaceMLEResults):
         elif isinstance(random_errors, (rv_continuous, rv_discrete)):
             params = random_errors.fit(self.resid)
             eps = random_errors.rvs(*params, size=(nsimulations, repetitions))
-        elif isinstance(random_errors, _distn_infrastructure.rv_frozen):
+        elif isinstance(random_errors, rv_frozen):
             eps = random_errors.rvs(size=(nsimulations, repetitions))
         else:
             raise ValueError("Argument random_errors has unexpected value!")
@@ -2261,20 +2293,20 @@ class PredictionResults:
                     )
                     # anchor
                     anchor = start_smooth + i
-            sim_results.append(
-                results.simulate(
-                    ndynamic,
-                    anchor=anchor_dynamic,
-                    repetitions=simulate_repetitions,
-                    **simulate_kwargs,
+            if ndynamic:
+                sim_results.append(
+                    results.simulate(
+                        ndynamic,
+                        anchor=anchor_dynamic,
+                        repetitions=simulate_repetitions,
+                        **simulate_kwargs,
+                    )
                 )
-            )
-            self.simulation_results = np.concatenate(sim_results, axis=0)
-            # if self.use_pandas:
-            #     self.simulation_results = pd.DataFrame(
-            #         self.simulation_results, index=self.row_labels,
-            #         columns=sim_results[0].columns
-            #     )
+            if sim_results and isinstance(sim_results[0], pd.DataFrame):
+                self.simulation_results = pd.concat(sim_results, axis=0)
+            else:
+                self.simulation_results = np.concatenate(sim_results, axis=0)
+            self.forecast_variance = self.simulation_results.var(1)
         else:  # method == 'exact'
             steps = np.ones(ndynamic + nsmooth)
             if ndynamic > 0:
