@@ -2,11 +2,11 @@ import numpy as np
 import pandas as pd
 from scipy.special import inv_boxcox
 from scipy.stats import (
-    _distn_infrastructure,
     boxcox,
     rv_continuous,
     rv_discrete,
 )
+from scipy.stats.distributions import rv_frozen
 
 from statsmodels.base.data import PandasData
 from statsmodels.base.model import Results
@@ -84,7 +84,7 @@ class HoltWintersResults(Results):
         mle_retvals=None,
     ):
         self.data = model.data
-        super(HoltWintersResults, self).__init__(model, params)
+        super().__init__(model, params)
         self._model = model
         self._sse = sse
         self._aic = aic
@@ -155,22 +155,6 @@ class HoltWintersResults(Results):
         """
         return self._optimized
 
-    @property
-    def slope(self):
-        """
-        An array of the slope values that make up the fitted values.
-
-        .. deprecated:: 0.12
-
-           Use the trend property instead.
-        """
-        import warnings
-
-        warnings.warn(
-            "slope is deprecated and will be removed after 0.13", FutureWarning
-        )
-        return self._trend
-
     @property
     def trend(self):
         """
@@ -283,14 +267,16 @@ class HoltWintersResults(Results):
         """
         try:
             freq = getattr(self.model._index, "freq", 1)
-            if isinstance(freq, int):
-                start = self.model._index.shape[0]
-                end = start + steps - 1
-            else:
+            if not isinstance(freq, int) and isinstance(
+                self.model._index, (pd.DatetimeIndex, pd.PeriodIndex)
+            ):
                 start = self.model._index[-1] + freq
                 end = self.model._index[-1] + steps * freq
+            else:
+                start = self.model._index.shape[0]
+                end = start + steps - 1
             return self.model.predict(self.params, start=start, end=end)
-        except (AttributeError, ValueError):
+        except AttributeError:
             # May occur when the index does not have a freq
             return self.model._predict(h=steps, **self.params).fcastvalues
 
@@ -369,6 +355,8 @@ class HoltWintersResults(Results):
         def _fmt(x):
             abs_x = np.abs(x)
             scale = 1
+            if np.isnan(x):
+                return f"{str(x):>20}"
             if abs_x != 0:
                 scale = int(np.log10(abs_x))
             if scale > 4 or scale < -3:
@@ -680,7 +668,7 @@ class HoltWintersResults(Results):
             resid = self.model._y - fitted
         else:
             resid = (self.model._y - fitted) / fitted
-        sigma = np.sqrt(np.sum(resid ** 2) / (len(resid) - n_params))
+        sigma = np.sqrt(np.sum(resid**2) / (len(resid) - n_params))
 
         # get random error eps
         if isinstance(random_errors, np.ndarray):
@@ -710,7 +698,7 @@ class HoltWintersResults(Results):
         elif isinstance(random_errors, (rv_continuous, rv_discrete)):
             params = random_errors.fit(resid)
             eps = random_errors.rvs(*params, size=(nsimulations, repetitions))
-        elif isinstance(random_errors, _distn_infrastructure.rv_frozen):
+        elif isinstance(random_errors, rv_frozen):
             eps = random_errors.rvs(size=(nsimulations, repetitions))
         else:
             raise ValueError("Argument random_errors has unexpected value!")
