@@ -2,6 +2,8 @@
 Author: Terence L van Zyl
 Modified: Kevin Sheppard
 """
+from statsmodels.compat.pytest import pytest_warns
+
 import os
 import re
 import warnings
@@ -12,11 +14,7 @@ import pandas as pd
 import pytest
 import scipy.stats
 
-from statsmodels.tools.sm_exceptions import (
-    ConvergenceWarning,
-    EstimationWarning,
-    ValueWarning,
-)
+from statsmodels.tools.sm_exceptions import ConvergenceWarning, ValueWarning
 from statsmodels.tsa.holtwinters import (
     PY_SMOOTHERS,
     SMOOTHERS,
@@ -35,13 +33,72 @@ from statsmodels.tsa.holtwinters._smoothers import (
 )
 
 base, _ = os.path.split(os.path.abspath(__file__))
-housing_data = pd.read_csv(os.path.join(base, "results", "housing-data.csv"))
-housing_data = housing_data.set_index("DATE")
+housing_data = pd.read_csv(
+    os.path.join(base, "results", "housing-data.csv"),
+    index_col="DATE",
+    parse_dates=True,
+)
 housing_data = housing_data.asfreq("MS")
 
 SEASONALS = ("add", "mul", None)
 TRENDS = ("add", "mul", None)
 
+# aust = pd.read_json(aust_json, typ='Series').sort_index()
+data = [
+    41.727457999999999,
+    24.04185,
+    32.328102999999999,
+    37.328707999999999,
+    46.213152999999998,
+    29.346326000000001,
+    36.482909999999997,
+    42.977719,
+    48.901524999999999,
+    31.180221,
+    37.717880999999998,
+    40.420211000000002,
+    51.206862999999998,
+    31.887228,
+    40.978262999999998,
+    43.772491000000002,
+    55.558566999999996,
+    33.850915000000001,
+    42.076383,
+    45.642291999999998,
+    59.766779999999997,
+    35.191876999999998,
+    44.319737000000003,
+    47.913736,
+]
+index = [
+    "2005-03-01 00:00:00",
+    "2005-06-01 00:00:00",
+    "2005-09-01 00:00:00",
+    "2005-12-01 00:00:00",
+    "2006-03-01 00:00:00",
+    "2006-06-01 00:00:00",
+    "2006-09-01 00:00:00",
+    "2006-12-01 00:00:00",
+    "2007-03-01 00:00:00",
+    "2007-06-01 00:00:00",
+    "2007-09-01 00:00:00",
+    "2007-12-01 00:00:00",
+    "2008-03-01 00:00:00",
+    "2008-06-01 00:00:00",
+    "2008-09-01 00:00:00",
+    "2008-12-01 00:00:00",
+    "2009-03-01 00:00:00",
+    "2009-06-01 00:00:00",
+    "2009-09-01 00:00:00",
+    "2009-12-01 00:00:00",
+    "2010-03-01 00:00:00",
+    "2010-06-01 00:00:00",
+    "2010-09-01 00:00:00",
+    "2010-12-01 00:00:00",
+]
+idx = pd.to_datetime(index)
+aust = pd.Series(data, index=pd.DatetimeIndex(idx, freq=pd.infer_freq(idx)))
+
 
 @pytest.fixture(scope="module")
 def ses():
@@ -81,7 +138,7 @@ def _simple_dbl_exp_smoother(x, alpha, beta, l0, b0, nforecast=0):
     return lvals, b, f, err, xhat
 
 
-class TestHoltWinters(object):
+class TestHoltWinters:
     @classmethod
     def setup_class(cls):
         # Changed for backwards compatibility with pandas
@@ -239,63 +296,6 @@ class TestHoltWinters(object):
         )
         cls.livestock2_livestock = livestock2_livestock
 
-        # aust = pd.read_json(aust_json, typ='Series').sort_index()
-        data = [
-            41.727457999999999,
-            24.04185,
-            32.328102999999999,
-            37.328707999999999,
-            46.213152999999998,
-            29.346326000000001,
-            36.482909999999997,
-            42.977719,
-            48.901524999999999,
-            31.180221,
-            37.717880999999998,
-            40.420211000000002,
-            51.206862999999998,
-            31.887228,
-            40.978262999999998,
-            43.772491000000002,
-            55.558566999999996,
-            33.850915000000001,
-            42.076383,
-            45.642291999999998,
-            59.766779999999997,
-            35.191876999999998,
-            44.319737000000003,
-            47.913736,
-        ]
-        index = [
-            "2005-03-01 00:00:00",
-            "2005-06-01 00:00:00",
-            "2005-09-01 00:00:00",
-            "2005-12-01 00:00:00",
-            "2006-03-01 00:00:00",
-            "2006-06-01 00:00:00",
-            "2006-09-01 00:00:00",
-            "2006-12-01 00:00:00",
-            "2007-03-01 00:00:00",
-            "2007-06-01 00:00:00",
-            "2007-09-01 00:00:00",
-            "2007-12-01 00:00:00",
-            "2008-03-01 00:00:00",
-            "2008-06-01 00:00:00",
-            "2008-09-01 00:00:00",
-            "2008-12-01 00:00:00",
-            "2009-03-01 00:00:00",
-            "2009-06-01 00:00:00",
-            "2009-09-01 00:00:00",
-            "2009-12-01 00:00:00",
-            "2010-03-01 00:00:00",
-            "2010-06-01 00:00:00",
-            "2010-09-01 00:00:00",
-            "2010-12-01 00:00:00",
-        ]
-        aust = pd.Series(data, index)
-        aust.index = pd.DatetimeIndex(
-            aust.index, freq=pd.infer_freq(aust.index)
-        )
         cls.aust = aust
         cls.start_params = [
             1.5520372162082909e-09,
@@ -358,7 +358,10 @@ class TestHoltWinters(object):
     @pytest.mark.xfail(reason="Optimizer does not converge", strict=False)
     def test_forecast(self):
         fit1 = ExponentialSmoothing(
-            self.aust, seasonal_periods=4, trend="add", seasonal="add",
+            self.aust,
+            seasonal_periods=4,
+            trend="add",
+            seasonal="add",
         ).fit(method="bh", use_brute=True)
         assert_almost_equal(
             fit1.forecast(steps=4), [60.9542, 36.8505, 46.1628, 50.1272], 3
@@ -491,6 +494,7 @@ class TestHoltWinters(object):
         assert_almost_equal(fit1.params["initial_level"], 263.96, 1)
         assert_almost_equal(fit1.params["initial_trend"], np.NaN, 2)
         assert_almost_equal(fit1.sse, 6761.35, 2)  # 6080.26
+        assert isinstance(fit1.summary().as_text(), str)
 
         assert_almost_equal(fit4.params["smoothing_level"], 0.98, 2)
         assert_almost_equal(fit4.params["smoothing_trend"], 0.00, 2)
@@ -498,13 +502,15 @@ class TestHoltWinters(object):
         assert_almost_equal(fit4.params["initial_level"], 257.36, 2)
         assert_almost_equal(fit4.params["initial_trend"], 6.64, 2)
         assert_almost_equal(fit4.sse, 6036.56, 2)  # 6080.26
+        assert isinstance(fit4.summary().as_text(), str)
 
         assert_almost_equal(fit5.params["smoothing_level"], 0.97, 2)
         assert_almost_equal(fit5.params["smoothing_trend"], 0.00, 2)
         assert_almost_equal(fit5.params["damping_trend"], 0.98, 2)
         assert_almost_equal(fit5.params["initial_level"], 258.95, 1)
         assert_almost_equal(fit5.params["initial_trend"], 1.04, 2)
-        assert_almost_equal(fit5.sse, 6082.00, 1)  # 6100.11
+        assert_almost_equal(fit5.sse, 6082.00, 0)  # 6100.11
+        assert isinstance(fit5.summary().as_text(), str)
 
     def test_holt_damp_r(self):
         # Test the damping parameters against the R forecast packages `ets`
@@ -512,8 +518,11 @@ class TestHoltWinters(object):
         # livestock2_livestock <- c(...)
         # res <- ets(livestock2_livestock, model='AAN', damped_trend=TRUE,
         #            phi=0.98)
-        with pytest.warns(FutureWarning):
-            mod = Holt(self.livestock2_livestock, damped_trend=True)
+        mod = Holt(
+            self.livestock2_livestock,
+            damped_trend=True,
+            initialization_method="estimated",
+        )
         params = {
             "smoothing_level": 0.97402626,
             "smoothing_trend": 0.00010006,
@@ -528,6 +537,16 @@ class TestHoltWinters(object):
         for key in params.keys():
             assert_allclose(fit.params[key], params[key])
 
+        with mod.fix_params(params):
+            opt_fit = mod.fit(optimized=True)
+        assert_allclose(fit.sse, opt_fit.sse)
+        assert_allclose(
+            opt_fit.params["initial_trend"], params["initial_trend"]
+        )
+        alt_params = {k: v for k, v in params.items() if "level" not in k}
+        with mod.fix_params(alt_params):
+            alt_fit = mod.fit(optimized=True)
+        assert not np.allclose(alt_fit.trend[0], opt_fit.trend[0])
         # Summary output
         # print(res$mse)
         assert_allclose(fit.sse / mod.nobs, 195.4397924865488, atol=1e-3)
@@ -799,7 +818,9 @@ def test_invalid_seasonal(seasonal):
 
 def test_2d_data():
     with pytest.raises(ValueError):
-        ExponentialSmoothing(pd.concat([housing_data, housing_data], 1)).fit()
+        ExponentialSmoothing(
+            pd.concat([housing_data, housing_data], axis=1)
+        ).fit()
 
 
 def test_infer_freq():
@@ -828,15 +849,18 @@ def test_start_params(trend, seasonal):
         method="basinhopping",
         minimize_kwargs={"minimizer_kwargs": {"method": "SLSQP"}},
     )
+    assert isinstance(res.summary().as_text(), str)
     assert res2.sse < 1.01 * res.sse
     assert isinstance(res2.params, dict)
 
 
 def test_no_params_to_optimize():
-    with pytest.warns(FutureWarning):
-        mod = ExponentialSmoothing(housing_data)
-    with pytest.warns(EstimationWarning):
-        mod.fit(smoothing_level=0.5, initial_level=housing_data.iloc[0])
+    mod = ExponentialSmoothing(
+        housing_data,
+        initial_level=housing_data.iloc[0],
+        initialization_method="known",
+    )
+    mod.fit(smoothing_level=0.5)
 
 
 def test_invalid_start_param_length():
@@ -850,8 +874,9 @@ def test_basin_hopping(reset_randomstate):
         housing_data, trend="add", initialization_method="estimated"
     )
     res = mod.fit()
-    with pytest.warns(FutureWarning):
-        res2 = mod.fit(use_basinhopping=True)
+    res2 = mod.fit(method="basinhopping")
+    assert isinstance(res.summary().as_text(), str)
+    assert isinstance(res2.summary().as_text(), str)
     # Basin hopping occasionally produces a slightly larger objective
     tol = 1e-5
     assert res2.sse <= res.sse + tol
@@ -868,6 +893,8 @@ def test_debiased():
     assert np.any(res.fittedvalues != res2.fittedvalues)
     err2 = housing_data.iloc[:, 0] - res2.fittedvalues
     assert_almost_equal(err2.mean(), 0.0)
+    assert isinstance(res.summary().as_text(), str)
+    assert isinstance(res2.summary().as_text(), str)
 
 
 @pytest.mark.smoke
@@ -882,10 +909,12 @@ def test_float_boxcox(trend, seasonal):
         use_boxcox=0.5,
     ).fit()
     assert_allclose(res.params["use_boxcox"], 0.5)
-    with pytest.warns(FutureWarning):
-        res = ExponentialSmoothing(
-            housing_data, trend=trend, seasonal=seasonal
-        ).fit(use_boxcox = 0.5)
+    res = ExponentialSmoothing(
+        housing_data,
+        trend=trend,
+        seasonal=seasonal,
+        use_boxcox=0.5,
+    ).fit()
     assert_allclose(res.params["use_boxcox"], 0.5)
 
 
@@ -899,11 +928,10 @@ def test_equivalence_cython_python(trend, seasonal):
         initialization_method="estimated",
     )
 
-    with pytest.warns(None):
-        # Overflow in mul-mul case fixed
-        res = mod.fit()
+    # Overflow in mul-mul case fixed
+    res = mod.fit()
+    assert isinstance(res.summary().as_text(), str)
 
-    res.summary()  # Smoke test
     params = res.params
     nobs = housing_data.shape[0]
     y = np.squeeze(np.asarray(housing_data))
@@ -939,6 +967,7 @@ def test_equivalence_cython_python(trend, seasonal):
 def test_direct_holt_add():
     mod = SimpleExpSmoothing(housing_data, initialization_method="estimated")
     res = mod.fit()
+    assert isinstance(res.summary().as_text(), str)
     x = np.squeeze(np.asarray(mod.endog))
     alpha = res.params["smoothing_level"]
     l, b, f, _, xhat = _simple_dbl_exp_smoother(
@@ -973,6 +1002,7 @@ def test_direct_holt_add():
         f, res.level.iloc[-1] + res.trend.iloc[-1] * np.array([1, 2, 3, 4, 5])
     )
     assert_allclose(f, res.forecast(5))
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_integer_array(reset_randomstate):
@@ -1006,6 +1036,38 @@ def test_damping_trend_zero():
     assert_allclose(pred1, pred2, atol=1e-10)
 
 
+def test_different_inputs():
+    array_input_add = [10, 20, 30, 40, 50]
+    series_index_add = pd.date_range(
+        start="2000-1-1", periods=len(array_input_add)
+    )
+    series_input_add = pd.Series(array_input_add, series_index_add)
+
+    array_input_mul = [2, 4, 8, 16, 32]
+    series_index_mul = pd.date_range(
+        start="2000-1-1", periods=len(array_input_mul)
+    )
+    series_input_mul = pd.Series(array_input_mul, series_index_mul)
+
+    fit1 = ExponentialSmoothing(array_input_add, trend="add").fit()
+    fit2 = ExponentialSmoothing(series_input_add, trend="add").fit()
+    fit3 = ExponentialSmoothing(array_input_mul, trend="mul").fit()
+    fit4 = ExponentialSmoothing(series_input_mul, trend="mul").fit()
+
+    assert_almost_equal(fit1.predict(), [60], 1)
+    assert_almost_equal(fit1.predict(start=5, end=7), [60, 70, 80], 1)
+    assert_almost_equal(fit2.predict(), [60], 1)
+    assert_almost_equal(
+        fit2.predict(start="2000-1-6", end="2000-1-8"), [60, 70, 80], 1
+    )
+    assert_almost_equal(fit3.predict(), [64], 1)
+    assert_almost_equal(fit3.predict(start=5, end=7), [64, 128, 256], 1)
+    assert_almost_equal(fit4.predict(), [64], 1)
+    assert_almost_equal(
+        fit4.predict(start="2000-1-6", end="2000-1-8"), [64, 128, 256], 1
+    )
+
+
 @pytest.fixture
 def austourists():
     # austourists dataset from fpp2 package
@@ -1466,28 +1528,27 @@ def test_simulate_expected_r(
         return
 
     # create HoltWintersResults object with same parameters as in R
-    with pytest.warns(FutureWarning):
-        fit = ExponentialSmoothing(
-            austourists,
-            seasonal_periods=4,
-            trend=trend,
-            seasonal=seasonal,
-            damped_trend=damped,
-        ).fit(
-            smoothing_level=state["alpha"],
-            smoothing_trend=state["beta"],
-            smoothing_seasonal=state["gamma"],
-            damping_trend=state["phi"],
-            optimized=False,
-        )
+    fit = ExponentialSmoothing(
+        austourists,
+        seasonal_periods=4,
+        trend=trend,
+        seasonal=seasonal,
+        damped_trend=damped,
+    ).fit(
+        smoothing_level=state["alpha"],
+        smoothing_trend=state["beta"],
+        smoothing_seasonal=state["gamma"],
+        damping_trend=state["phi"],
+        optimized=False,
+    )
 
     # set the same final state as in R
-    fit.level[-1] = state["l"]
-    fit.trend[-1] = state["b"]
-    fit.season[-1] = state["s1"]
-    fit.season[-2] = state["s2"]
-    fit.season[-3] = state["s3"]
-    fit.season[-4] = state["s4"]
+    fit._level[-1] = state["l"]
+    fit._trend[-1] = state["b"]
+    fit._season[-1] = state["s1"]
+    fit._season[-2] = state["s2"]
+    fit._season[-3] = state["s3"]
+    fit._season[-4] = state["s4"]
 
     # for MMM with damped trend the fit fails
     if np.any(np.isnan(fit.fittedvalues)):
@@ -1587,11 +1648,12 @@ def test_error_boxcox():
     y = np.random.standard_normal(100)
     with pytest.raises(TypeError, match="use_boxcox must be True"):
         ExponentialSmoothing(y, use_boxcox="a", initialization_method="known")
-    with pytest.raises(ValueError, match="initialization_method must be set"):
-        ExponentialSmoothing(y, use_boxcox=True)
+
+    mod = ExponentialSmoothing(y**2, use_boxcox=True)
+    assert isinstance(mod, ExponentialSmoothing)
 
     mod = ExponentialSmoothing(
-        y ** 2, use_boxcox=True, initialization_method="legacy-heuristic"
+        y**2, use_boxcox=True, initialization_method="legacy-heuristic"
     )
     with pytest.raises(ValueError, match="use_boxcox was set"):
         mod.fit(use_boxcox=False)
@@ -1624,7 +1686,10 @@ def test_error_initialization(ses):
         ExponentialSmoothing(ses, initial_seasonal=[1.0, 0.2, 0.05, 4])
     with pytest.raises(ValueError):
         ExponentialSmoothing(
-            ses, trend="add", initialization_method="known", initial_level=1.0,
+            ses,
+            trend="add",
+            initialization_method="known",
+            initial_level=1.0,
         )
     with pytest.raises(ValueError):
         ExponentialSmoothing(
@@ -1665,6 +1730,7 @@ def test_alternative_minimizers(method, ses):
     )
     assert_allclose(res.params["smoothing_level"], 0.77232545, rtol=1e-3)
     assert_allclose(res.params["initial_level"], 11.00359693, rtol=1e-3)
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_minimizer_kwargs_error(ses):
@@ -1680,6 +1746,7 @@ def test_minimizer_kwargs_error(ses):
     kwargs = {"minimizer_kwargs": {"method": "SLSQP"}}
     res = mod.fit(method="basinhopping", minimize_kwargs=kwargs)
     assert isinstance(res.params, dict)
+    assert isinstance(res.summary().as_text(), str)
 
 
 @pytest.mark.parametrize(
@@ -1746,6 +1813,7 @@ def test_fixed_basic(ses):
     with mod.fix_params({"smoothing_level": 0.3}):
         res = mod.fit()
     assert res.params["smoothing_level"] == 0.3
+    assert isinstance(res.summary().as_text(), str)
 
     mod = ExponentialSmoothing(
         ses, trend="add", damped_trend=True, initialization_method="estimated"
@@ -1753,6 +1821,7 @@ def test_fixed_basic(ses):
     with mod.fix_params({"damping_trend": 0.98}):
         res = mod.fit()
     assert res.params["damping_trend"] == 0.98
+    assert isinstance(res.summary().as_text(), str)
 
     mod = ExponentialSmoothing(
         ses, trend="add", seasonal="add", initialization_method="estimated"
@@ -1761,6 +1830,7 @@ def test_fixed_basic(ses):
         res = mod.fit()
     assert res.params["smoothing_seasonal"] == 0.1
     assert res.params["smoothing_level"] == 0.2
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_fixed_errors(ses):
@@ -1813,6 +1883,7 @@ def test_brute(ses, trend, seasonal):
     with mod.fix_params({"smoothing_level": 0.1}):
         res = mod.fit(use_brute=True)
     assert res.mle_retvals.success
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_fix_set_parameters(ses):
@@ -1870,12 +1941,11 @@ def test_initialization_methods(ses, method, trend, seasonal):
     )
     res = mod.fit()
     assert res.mle_retvals.success
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_attributes(ses):
     res = ExponentialSmoothing(ses, initialization_method="estimated").fit()
-    with pytest.warns(FutureWarning):
-        assert_allclose(res.trend, res.slope)
     assert res.k > 0
     assert res.resid.shape[0] == ses.shape[0]
     assert_allclose(res.fcastvalues, res.fittedfcast[-1:])
@@ -1883,13 +1953,14 @@ def test_attributes(ses):
 
 def test_summary_boxcox(ses):
     mod = ExponentialSmoothing(
-        ses ** 2, use_boxcox=True, initialization_method="heuristic"
+        ses**2, use_boxcox=True, initialization_method="heuristic"
     )
     with pytest.raises(ValueError, match="use_boxcox was set at model"):
         mod.fit(use_boxcox=True)
     res = mod.fit()
     summ = str(res.summary())
     assert re.findall(r"Box-Cox:[\s]*True", summ)
+    assert isinstance(res.summary().as_text(), str)
 
 
 def test_simulate(ses):
@@ -1897,6 +1968,7 @@ def test_simulate(ses):
         np.asarray(ses), initialization_method="heuristic"
     )
     res = mod.fit()
+    assert isinstance(res.summary().as_text(), str)
     with pytest.raises(ValueError, match="error must be"):
         res.simulate(10, error="unknown")
     with pytest.raises(ValueError, match="If random"):
@@ -1938,7 +2010,7 @@ def test_forecast_index_types(ses, index_typ):
     ses = ses.copy()
     ses.index = index[:-36]
 
-    with pytest.warns(warning):
+    with pytest_warns(warning):
         res = ExponentialSmoothing(
             ses,
             trend="add",
@@ -1946,7 +2018,7 @@ def test_forecast_index_types(ses, index_typ):
             initialization_method="heuristic",
             **kwargs
         ).fit()
-    with pytest.warns(warning):
+    with pytest_warns(warning):
         fcast = res.forecast(36)
     assert isinstance(fcast, pd.Series)
     pd.testing.assert_index_equal(fcast.index, fcast_index)
@@ -1957,9 +2029,125 @@ def test_boxcox_components(ses):
         ses + 1 - ses.min(), initialization_method="estimated", use_boxcox=True
     )
     res = mod.fit()
+    assert isinstance(res.summary().as_text(), str)
     with pytest.raises(AssertionError):
         # Must be different since level is not transformed
         assert_allclose(res.level, res.fittedvalues)
     assert not hasattr(res, "_untransformed_level")
     assert not hasattr(res, "_untransformed_trend")
     assert not hasattr(res, "_untransformed_seasonal")
+
+
+@pytest.mark.parametrize("repetitions", [1, 10])
+@pytest.mark.parametrize("random_errors", [None, "bootstrap"])
+def test_forecast_1_simulation(austourists, random_errors, repetitions):
+    # GH 7053
+    fit = ExponentialSmoothing(
+        austourists,
+        seasonal_periods=4,
+        trend="add",
+        seasonal="add",
+        damped_trend=True,
+        initialization_method="estimated",
+    ).fit()
+
+    sim = fit.simulate(
+        1, anchor=0, random_errors=random_errors, repetitions=repetitions
+    )
+    expected_shape = (1,) if repetitions == 1 else (1, repetitions)
+    assert sim.shape == expected_shape
+    sim = fit.simulate(
+        10, anchor=0, random_errors=random_errors, repetitions=repetitions
+    )
+    expected_shape = (10,) if repetitions == 1 else (10, repetitions)
+    assert sim.shape == expected_shape
+
+
+@pytest.mark.parametrize("trend", [None, "add"])
+@pytest.mark.parametrize("seasonal", [None, "add"])
+@pytest.mark.parametrize("nobs", [9, 10])
+def test_estimated_initialization_short_data(ses, trend, seasonal, nobs):
+    # GH 7319
+    res = ExponentialSmoothing(
+        ses[:nobs],
+        trend=trend,
+        seasonal=seasonal,
+        seasonal_periods=4,
+        initialization_method="estimated",
+    ).fit()
+    assert res.mle_retvals.success
+
+
+def test_invalid_index(reset_randomstate):
+    y = np.random.standard_normal(12 * 200)
+    df_y = pd.DataFrame(data=y)
+    # Can't have a freq here
+    df_y.index.freq = "d"
+
+    model = ExponentialSmoothing(
+        df_y,
+        seasonal_periods=12,
+        trend="add",
+        seasonal="add",
+        initialization_method="heuristic",
+    )
+    fitted = model.fit(optimized=True, use_brute=True)
+
+    fcast = fitted.forecast(steps=157200)
+    assert fcast.shape[0] == 157200
+
+    index = pd.date_range("2020-01-01", periods=2 * y.shape[0])
+    index = np.random.choice(index, size=df_y.shape[0], replace=False)
+    index = sorted(index)
+    df_y.index = index
+    assert isinstance(df_y.index, pd.DatetimeIndex)
+    assert df_y.index.freq is None
+    assert df_y.index.inferred_freq is None
+    with pytest.warns(ValueWarning, match="A date index has been provided"):
+        model = ExponentialSmoothing(
+            df_y,
+            seasonal_periods=12,
+            trend="add",
+            seasonal="add",
+            initialization_method="heuristic",
+        )
+    fitted = model.fit(optimized=True, use_brute=True)
+    with pytest.warns(ValueWarning, match="No supported"):
+        fitted.forecast(steps=157200)
+
+
+def test_initial_level():
+    # GH 8634
+    series = [0.0, 0.0, 0.0, 100.0, 0.0, 0.0, 0.0]
+    es = ExponentialSmoothing(
+        series, initialization_method="known", initial_level=20.0
+    )
+    es_fit = es.fit()
+    es_fit.params
+    assert_allclose(es_fit.params["initial_level"], 20.0)
+
+
+def test_all_initial_values():
+    fit1 = ExponentialSmoothing(
+        aust,
+        seasonal_periods=4,
+        trend="add",
+        seasonal="mul",
+        initialization_method="estimated",
+    ).fit()
+    lvl = np.round(fit1.params["initial_level"])
+    trend = np.round(fit1.params["initial_trend"], 1)
+    seas = np.round(fit1.params["initial_seasons"], 1)
+    fit2 = ExponentialSmoothing(
+        aust,
+        seasonal_periods=4,
+        trend="add",
+        seasonal="mul",
+        initialization_method="known",
+        initial_level=lvl,
+        initial_trend=trend,
+        initial_seasonal=seas,
+    ).fit()
+    assert_allclose(fit2.params["initial_level"], lvl)
+    assert_allclose(fit2.params["initial_trend"], trend)
+    assert_allclose(fit2.params["initial_seasons"], seas)
