@@ -407,7 +407,7 @@ mumpspc = [0.29791319, 0.41467956, 1.13061404, 1.23267496,
            0.05628902, 0.00924054]
 
 
-class MarkovRegression(object):
+class MarkovRegression:
     @classmethod
     def setup_class(cls, true, endog, atol=1e-5, rtol=1e-7, **kwargs):
         cls.model = markov_regression.MarkovRegression(endog, **kwargs)
@@ -1284,10 +1284,12 @@ def test_exog_tvtp():
 
     params = np.r_[0.98209618, 0.05036498, 3.70877542, 9.55676298, 4.44181911]
     params_tvtp = params.copy()
-    params_tvtp[0] = mod2._untransform_logistic(
-        np.r_[0.], np.r_[1 - params[0]])
-    params_tvtp[1] = mod2._untransform_logistic(
-        np.r_[0.], np.r_[1 - params[1]])
+    params_tvtp[0] = np.squeeze(
+        mod2._untransform_logistic(np.r_[0.], np.r_[1 - params[0]])
+    )
+    params_tvtp[1] = np.squeeze(
+        mod2._untransform_logistic(np.r_[0.], np.r_[1 - params[1]])
+    )
 
     res1 = mod1.smooth(params)
     res2 = mod2.smooth(params_tvtp)
