@@ -4,8 +4,6 @@ Tests for the generic MLEModel
 Author: Chad Fulton
 License: Simplified-BSD
 """
-from statsmodels.compat.pandas import NumericIndex
-
 import os
 import re
 import warnings
@@ -1189,13 +1187,13 @@ def test_states_index_dateindex():
 
 def test_states_index_int64index():
     nobs = 10
-    ix = NumericIndex(np.arange(10))
+    ix = pd.Index(np.arange(10))
     endog = pd.Series(np.zeros(nobs), index=ix)
 
     mod = sarimax.SARIMAX(endog, order=(2, 0, 0))
     res = mod.smooth([0.5, 0.1, 1.0])
 
-    predicted_ix = NumericIndex(np.arange(11))
+    predicted_ix = pd.Index(np.arange(11))
     cols = pd.Index(['state.0', 'state.1'])
 
     check_states_index(res.states, ix, predicted_ix, cols)
@@ -1227,3 +1225,15 @@ def test_states_index_rangeindex():
     cols = pd.Index(['state.0', 'state.1'])
 
     check_states_index(res.states, ix, predicted_ix, cols)
+
+
+def test_invalid_kwargs():
+    endog = [0, 0, 1.]
+    # Make sure we can create basic SARIMAX
+    sarimax.SARIMAX(endog)
+    # Now check that it raises a warning if we add an invalid keyword argument
+    with pytest.warns(FutureWarning):
+        sarimax.SARIMAX(endog, invalid_kwarg=True)
+    # (Note: once deprectation is completed in v0.15, switch to checking for
+    # a TypeError, as below)
+    # assert_raises(TypeError, sarimax.SARIMAX, endog, invalid_kwarg=True)
