@@ -323,7 +323,7 @@ class VARMAX(MLEModel):
         # A. Run a multivariate regression to get beta estimates
         endog = pd.DataFrame(self.endog.copy())
         endog = endog.interpolate()
-        endog = endog.fillna(method='backfill').values
+        endog = np.require(endog.fillna(method='backfill'), requirements="W")
         exog = None
         if self.k_trend > 0 and self.k_exog > 0:
             exog = np.c_[self._trend_data, self.exog]
@@ -355,7 +355,7 @@ class VARMAX(MLEModel):
         ar_params = []
         k_ar = self.k_ar if self.k_ar > 0 else 1
         mod_ar = var_model.VAR(endog)
-        res_ar = mod_ar.fit(maxlags=k_ar, ic=None, trend='nc')
+        res_ar = mod_ar.fit(maxlags=k_ar, ic=None, trend='n')
         if self.k_ar > 0:
             ar_params = np.array(res_ar.params).T.ravel()
         endog = res_ar.resid
@@ -379,7 +379,7 @@ class VARMAX(MLEModel):
         ma_params = []
         if self.k_ma > 0:
             mod_ma = var_model.VAR(endog)
-            res_ma = mod_ma.fit(maxlags=self.k_ma, ic=None, trend='nc')
+            res_ma = mod_ma.fit(maxlags=self.k_ma, ic=None, trend='n')
             ma_params = np.array(res_ma.params.T).ravel()
 
             # Test for invertibility
@@ -454,16 +454,14 @@ class VARMAX(MLEModel):
 
         # 1. Intercept terms
         if self.k_trend > 0:
-            for i in self.polynomial_trend.nonzero()[0]:
-                if i == 0:
-                    param_names += ['intercept.%s' % endog_names[j]
-                                    for j in range(self.k_endog)]
-                elif i == 1:
-                    param_names += ['drift.%s' % endog_names[j]
-                                    for j in range(self.k_endog)]
-                else:
-                    param_names += ['trend.%d.%s' % (i, endog_names[j])
-                                    for j in range(self.k_endog)]
+            for j in range(self.k_endog):
+                for i in self.polynomial_trend.nonzero()[0]:
+                    if i == 0:
+                        param_names += ['intercept.%s' % endog_names[j]]
+                    elif i == 1:
+                        param_names += ['drift.%s' % endog_names[j]]
+                    else:
+                        param_names += ['trend.%d.%s' % (i, endog_names[j])]
 
         # 2. AR terms
         param_names += [
@@ -724,7 +722,7 @@ class VARMAX(MLEModel):
             # just += later
             if not self.mle_regression:
                 zero = np.array(0, dtype=params.dtype)
-                self.ssm[self._idx_state_intercept] = zero
+                self.ssm['state_intercept', :] = zero
 
             trend_params = params[self._params_trend].reshape(
                 self.k_endog, self.k_trend).T
@@ -734,7 +732,8 @@ class VARMAX(MLEModel):
                 intercept = np.dot(self._trend_data[1:], trend_params)
             self.ssm[self._idx_state_intercept] += intercept.T
 
-            if self._final_trend is not None and not self._trend_is_const:
+            if (self._final_trend is not None
+                    and self._idx_state_intercept[-1].stop == -1):
                 self.ssm['state_intercept', :self.k_endog, -1:] += np.dot(
                     self._final_trend, trend_params).T
 
@@ -920,6 +919,37 @@ class VARMAXResults(MLEResults):
 
         return res
 
+    @contextlib.contextmanager
+    def _set_final_exog(self, exog):
+        """
+        Set the final state intercept value using out-of-sample `exog` / trend
+
+        Parameters
+        ----------
+        exog : ndarray
+            Out-of-sample `exog` values, usually produced by
+            `_validate_out_of_sample_exog` to ensure the correct shape (this
+            method does not do any additional validation of its own).
+        out_of_sample : int
+            Number of out-of-sample periods.
+
+        Notes
+        -----
+        This context manager calls the model-level context manager and
+        additionally updates the last element of filter_results.state_intercept
+        appropriately.
+        """
+        mod = self.model
+        with mod._set_final_exog(exog):
+            cache_value = self.filter_results.state_intercept[:, -1]
+            mod.update(self.params)
+            self.filter_results.state_intercept[:mod.k_endog, -1] = (
+                mod['state_intercept', :mod.k_endog, -1])
+            try:
+                yield
+            finally:
+                self.filter_results.state_intercept[:, -1] = cache_value
+
     @contextlib.contextmanager
     def _set_final_predicted_state(self, exog, out_of_sample):
         """
@@ -970,8 +1000,9 @@ class VARMAXResults(MLEResults):
                 self.filter_results.predicted_state[:, -1] = np.nan
 
     @Appender(MLEResults.get_prediction.__doc__)
-    def get_prediction(self, start=None, end=None, dynamic=False, index=None,
-                       exog=None, **kwargs):
+    def get_prediction(self, start=None, end=None, dynamic=False,
+                       information_set='predicted', index=None, exog=None,
+                       **kwargs):
         if start is None:
             start = 0
 
@@ -989,11 +1020,12 @@ class VARMAXResults(MLEResults):
                 self.model.trend_offset + self.nobs)
 
         # Get the prediction
-        with self.model._set_final_exog(exog):
+        with self._set_final_exog(exog):
             with self._set_final_predicted_state(exog, out_of_sample):
                 out = super(VARMAXResults, self).get_prediction(
-                    start=start, end=end, dynamic=dynamic, index=index,
-                    exog=exog, extend_kwargs=extend_kwargs, **kwargs)
+                    start=start, end=end, dynamic=dynamic,
+                    information_set=information_set, index=index, exog=exog,
+                    extend_kwargs=extend_kwargs, **kwargs)
         return out
 
     @Appender(MLEResults.simulate.__doc__)
@@ -1029,7 +1061,8 @@ class VARMAXResults(MLEResults):
 
         return out
 
-    def _news_previous_results(self, previous, start, end, periods):
+    def _news_previous_results(self, previous, start, end, periods,
+                               state_index=None):
         # We need to figure out the out-of-sample exog, so that we can add back
         # in the last exog, predicted state
         exog = None
@@ -1064,7 +1097,7 @@ class VARMAXResults(MLEResults):
 
             out = self.smoother_results.news(
                 previous.smoother_results, start=start, end=end,
-                revised=revised_results)
+                revised=revised_results, state_index=state_index)
         return out
 
     @Appender(MLEResults.summary.__doc__)
